/* A Bison parser, made by GNU Bison 3.0.5.  */

/* Bison implementation for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Bison version.  */
#define YYBISON_VERSION "3.0.5"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Push parsers.  */
#define YYPUSH 0

/* Pull parsers.  */
#define YYPULL 1




/* Copy the first part of user declarations.  */
#line 17 "gram.y" /* yacc.c:339  */

/*
 *  pmlogrewrite parser
 */
#include "pmapi.h"
#include "libpcp.h"
#include "logger.h"
#include <errno.h>
#include <assert.h>

#define PM_TEXT_TYPE_MASK (PM_TEXT_ONELINE | PM_TEXT_HELP)

static indomspec_t	*current_indomspec;
static int		current_star_indom;
static int		do_walk_indom;
static int		star_domain;

static metricspec_t	*current_metricspec;
static int		current_star_metric;
static int		star_cluster;
static int		do_walk_metric;
static int		output = OUTPUT_ALL;
static int		one_inst;
static char		*one_name;

static textspec_t	*current_textspec;
static int		do_walk_text;

static int		current_label_id;
static char *		current_label_name;
static char *		current_label_value;
static int		current_label_instance;
static labelspec_t	*current_labelspec;
static int		do_walk_label;

static char *
dupcat(const char* s1, const char* s2)
{
    size_t	len;
    char	*s;

    len = strlen(s1) + strlen(s2) + 1;
    s = malloc(len);
    if (s == NULL) {
	fprintf(stderr, "dupcat malloc(%d) failed: %s\n",
		(int)len, strerror(errno));
	abandon();
	/*NOTREACHED*/
    }

    pmsprintf(s, len, "%s%s", s1, s2);
    return s;
}
 
static char *
add_quotes(const char *s)
{
    size_t	len;
    char	*s1;

    len = strlen(s) + 2 + 1;
    s1 = malloc(len);
    if (s1 == NULL) {
	fprintf(stderr, "add_quotes malloc(%d) failed: %s\n",
		(int)len, strerror(errno));
	abandon();
	/*NOTREACHED*/
    }

    pmsprintf(s1, len, "\"%s\"", s);
    return s1;
}
 
indomspec_t *
walk_indom(int mode)
{
    static indomspec_t	*ip;

    if (do_walk_indom) {
	if (mode == W_START)
	    ip = indom_root;
	else
	    ip = ip->i_next;
	while (ip != NULL && pmInDom_domain(ip->old_indom) != star_domain)
	    ip = ip->i_next;
    }
    else {
	if (mode == W_START)
	    ip = current_indomspec;
	else
	    ip = NULL;
    }

    return ip;
}

metricspec_t *
walk_metric(int mode, int flag, char *which, int dupok)
{
    static metricspec_t	*mp;

    if (do_walk_metric) {
	if (mode == W_START)
	    mp = metric_root;
	else
	    mp = mp->m_next;
	while (mp != NULL) {
	    if (pmID_domain(mp->old_desc.pmid) == star_domain &&
		(star_cluster == PM_ID_NULL || star_cluster == pmID_cluster(mp->old_desc.pmid)))
		break;
	    mp = mp->m_next;
	}
    }
    else {
	if (mode == W_START)
	    mp = current_metricspec;
	else
	    mp = NULL;
    }

    if (mp != NULL) {
	if (!dupok && (mp->flags & flag)) {
	    pmsprintf(mess, sizeof(mess), "Duplicate %s clause for metric %s", which, mp->old_name);
	    yyerror(mess);
	}
	if (flag != METRIC_DELETE) {
	    if (mp->flags & METRIC_DELETE) {
		pmsprintf(mess, sizeof(mess), "Conflicting %s clause for deleted metric %s", which, mp->old_name);
		yyerror(mess);
	    }
	}
	else {
	    if (mp->flags & (~METRIC_DELETE)) {
		pmsprintf(mess, sizeof(mess), "Conflicting delete and other clauses for metric %s", mp->old_name);
		yyerror(mess);
	    }
	}
    }

    return mp;
}

static const char *
textTypeStr(int type)
{
    switch(type)
	{
	case PM_TEXT_ONELINE:
	    return "one line";
	case PM_TEXT_HELP:
	    return "help";
	default:
	    break;
	}

    return "unknown";
}
 
textspec_t *
walk_text(int mode, int flag, char *which, int dupok)
{
    static textspec_t	*tp;

    if (do_walk_text) {
	if (mode == W_START)
	    tp = text_root;
	else
	    tp = tp->t_next;

	/* Only consider the active specs. */
	while (tp != NULL && (tp->flags & TEXT_ACTIVE) == 0)
	    tp = tp->t_next;
    }
    else {
	if (mode == W_START) {
	    tp = current_textspec;
	    if (tp)
		assert ((tp->flags & TEXT_ACTIVE));
	}
	else
	    tp = NULL;
    }

    if (tp != NULL) {
	tp->flags &= ~TEXT_ACTIVE;
	
	if (!dupok && (tp->flags & flag)) {
	    if ((tp->old_type & PM_TEXT_PMID)) {
		pmsprintf(mess, sizeof(mess), "Duplicate %s clause for %s text for metric %s",
			  which, textTypeStr(tp->old_type), pmIDStr(tp->old_id));
	    }
	    else {
		assert((tp->old_type & PM_TEXT_INDOM));
		pmsprintf(mess, sizeof(mess), "Duplicate %s clause for %s text for indom %s",
			  which, textTypeStr(tp->old_type), pmInDomStr(tp->old_id));
	    }
	    yyerror(mess);
	}
	if (flag != TEXT_DELETE) {
	    if (tp->flags & TEXT_DELETE) {
		if ((tp->old_type & PM_TEXT_PMID)) {
		    pmsprintf(mess, sizeof(mess), "Conflicting %s clause for deleted %s text for metric %s",
			      which, textTypeStr(tp->old_type), pmIDStr(tp->old_id));
		}
		else {
		    assert((tp->old_type & PM_TEXT_INDOM));
		    pmsprintf(mess, sizeof(mess), "Conflicting %s clause for deleted %s text for indom %s",
			      which, textTypeStr(tp->old_type), pmInDomStr(tp->old_id));
		}
		yyerror(mess);
	    }
	}
	else {
	    if (tp->flags & (~TEXT_DELETE)) {
		if ((tp->old_type & PM_TEXT_PMID)) {
		    pmsprintf(mess, sizeof(mess), "Conflicting delete and other clauses for %s text for metric %s",
			      textTypeStr(tp->old_type), pmIDStr(tp->old_id));
		}
		else {
		    assert((tp->old_type & PM_TEXT_INDOM));
		    pmsprintf(mess, sizeof(mess), "Conflicting delete and other clauses for %s text for indom %s",
			      textTypeStr(tp->old_type), pmInDomStr(tp->old_id));
		}
		yyerror(mess);
	    }
	}
    }

    return tp;
}

labelspec_t *
walk_label(int mode, int flag, char *which, int dupok)
{
    static labelspec_t	*lp;

    if (do_walk_label > 1) {
	if (mode == W_START)
	    lp = label_root;
	else
	    lp = lp->l_next;

	/* Only consider the active specs. */
	while (lp != NULL && (lp->flags & LABEL_ACTIVE) == 0)
	    lp = lp->l_next;
    }
    else {
	if (mode == W_START) {
	    lp = current_labelspec;
	    if (lp)
		assert ((lp->flags & LABEL_ACTIVE));
	}
	else
	    lp = NULL;
    }

    if (lp != NULL) {
	lp->flags &= ~LABEL_ACTIVE;
	
	if (!dupok && (lp->flags & flag)) {
	    if ((lp->old_type & PM_LABEL_CONTEXT)) {
		pmsprintf(mess, sizeof(mess), "Duplicate %s clause for context label",
			  which);
	    }
	    else if ((lp->old_type & PM_LABEL_DOMAIN)) {
		pmsprintf(mess, sizeof(mess), "Duplicate %s clause for label for domain %d",
			  which, pmID_domain(lp->old_id));
	    }
	    else if ((lp->old_type & PM_LABEL_CLUSTER)) {
		pmsprintf(mess, sizeof(mess), "Duplicate %s clause for label for cluster %d.%d",
			  which, pmID_domain(lp->old_id), pmID_cluster(lp->old_id));
	    }
	    else if ((lp->old_type & PM_LABEL_ITEM)) {
		pmsprintf(mess, sizeof(mess), "Duplicate %s clause for label for metric %s",
			  which, pmIDStr(lp->old_id));
	    }
	    else if ((lp->old_type & PM_LABEL_INDOM)) {
		pmsprintf(mess, sizeof(mess), "Duplicate %s clause for label for indom %s",
			  which, pmInDomStr(lp->old_id));
	    }
	    else if ((lp->old_type & PM_LABEL_INSTANCES)) {
		pmsprintf(mess, sizeof(mess), "Duplicate %s clause for label for the instances of indom %s",
			  which, pmInDomStr(lp->old_id));
	    }
	    yyerror(mess);
	}
	if (flag != LABEL_DELETE) {
	    if (lp->flags & LABEL_DELETE) {
		if ((lp->old_type & PM_LABEL_CONTEXT)) {
		    pmsprintf(mess, sizeof(mess), "Conflicting %s clause for deleted context label",
			      which);
		}
		else if ((lp->old_type & PM_LABEL_DOMAIN)) {
		    pmsprintf(mess, sizeof(mess), "Conflicting %s clause for deleted label for domain %d",
			      which, pmID_domain(lp->old_id));
		}
		else if ((lp->old_type & PM_LABEL_CLUSTER)) {
		    pmsprintf(mess, sizeof(mess), "Conflicting %s clause for deleted label for cluster %d.%d",
			      which, pmID_domain(lp->old_id), pmID_cluster(lp->old_id));
		}
		else if ((lp->old_type & PM_LABEL_ITEM)) {
		    pmsprintf(mess, sizeof(mess), "Conflicting %s clause for deleted label for metric %s",
			      which, pmIDStr(lp->old_id));
		}
		else if ((lp->old_type & PM_LABEL_INDOM)) {
		    pmsprintf(mess, sizeof(mess), "Conflicting %s clause for deleted label for indom %s",
			      which, pmInDomStr(lp->old_id));
		}
		else if ((lp->old_type & PM_LABEL_INSTANCES)) {
		    pmsprintf(mess, sizeof(mess), "Conflicting %s clause for deleted label for the instances of indom %s",
			      which, pmInDomStr(lp->old_id));
		}
		yyerror(mess);
	    }
	}
	else {
	    if (lp->flags & (~LABEL_DELETE)) {
		if ((lp->old_type & PM_LABEL_CONTEXT)) {
		    pmsprintf(mess, sizeof(mess), "Conflicting delete and other clauses for context label");
		}
		else if ((lp->old_type & PM_LABEL_DOMAIN)) {
		    pmsprintf(mess, sizeof(mess), "Conflicting delete and other clauses for label for domain %d",
			      pmID_domain(lp->old_id));
		}
		else if ((lp->old_type & PM_LABEL_CLUSTER)) {
		    pmsprintf(mess, sizeof(mess), "Conflicting delete and other clauses for label for cluster %d.%d",
			      pmID_domain(lp->old_id), pmID_cluster(lp->old_id));
		}
		else if ((lp->old_type & PM_LABEL_ITEM)) {
		    pmsprintf(mess, sizeof(mess), "Conflicting delete and other clauses for label for metric %s",
			      pmIDStr(lp->old_id));
		}
		else if ((lp->old_type & PM_LABEL_INDOM)) {
		    pmsprintf(mess, sizeof(mess), "Conflicting delete and other clauses for label for indom %s",
			      pmInDomStr(lp->old_id));
		}
		else if ((lp->old_type & PM_LABEL_INSTANCES)) {
		    pmsprintf(mess, sizeof(mess), "Conflicting delete and other clauses for label for the instances of indom %s",
			      pmInDomStr(lp->old_id));
		}
		yyerror(mess);
	    }
	}
    }

    return lp;
}

void
deactivate_labels(void)
{
    labelspec_t	*lp;
    for (lp = walk_label(W_START, LABEL_ACTIVE, "active", 0); lp != NULL; lp = walk_label(W_NEXT, 0, "", 0)) {
	lp->flags &= ~LABEL_ACTIVE;
    }
}

void
new_context_label()
{
    labelspec_t	*lp;
    int		sts;
    char	buf[PM_MAXLABELJSONLEN];

    /*
     * Ignore the other change specs which were identified and
     * add the new label to the generic context label change spec.
     * Search for an existing one first.
     */
    deactivate_labels();
    for (lp = label_root; lp != NULL; lp = lp->l_next) {
	if (lp->old_type == PM_LABEL_CONTEXT) {
	    assert (lp->old_id == PM_ID_NULL);
	    if (lp->old_label == NULL)
		break;
	}
    }

    /* Create one if none exists. */
    if (lp == NULL)
	lp = create_label(PM_LABEL_CONTEXT, PM_ID_NULL, 0, NULL, NULL);

    /* Add the new label to the label change spec. */
    pmsprintf(buf, sizeof(buf), "{%s:%s}",
	      current_label_name, current_label_value);
    if ((sts = __pmAddLabels(&lp->new_labels, buf, PM_LABEL_CONTEXT)) < 0) {
	pmsprintf(mess, sizeof(mess),
		  "Unable to add new context label %s: %s",
		  buf, pmErrStr(sts));
	yyerror(mess);
    }
    lp->new_labels->inst = 0;
    lp->flags |= LABEL_NEW;
}

void
new_domain_label(int domain)
{
    labelspec_t		*lp;
    int			sts;
    int			found = 0;
    __pmContext		*ctxp;
    __pmHashCtl		*hcp;
    __pmHashNode	*node;
    char		buf[PM_MAXLABELJSONLEN];

    /*
     * Ignore the change specs which were previously identified and instead
     * search the metadata for metrics in the given domain.
     * Create or re-use the change record for each one found. 
     */
    deactivate_labels();

    ctxp = __pmHandleToPtr(pmWhichContext());
    assert(ctxp != NULL);
    /*
     * Note: This application is single threaded, and once we have ctxp
     *	     the associated __pmContext will not move and will only be
     *	     accessed or modified synchronously either here or in libpcp.
     *	     We unlock the context so that it can be locked as required
     *	     within libpcp.
     */
    PM_UNLOCK(ctxp->c_lock);

    /* Prepare the JSON for the new label. */
    pmsprintf(buf, sizeof(buf), "{%s:%s}",
	      current_label_name, current_label_value);

    hcp = &ctxp->c_archctl->ac_log->l_hashpmid;
    for (node = __pmHashWalk(hcp, PM_HASH_WALK_START);
	 node != NULL;
	 node = __pmHashWalk(hcp, PM_HASH_WALK_NEXT)) {
	if (pmID_domain(node->key) != domain)
	    continue;

	/*
	 * A metric in this domain exists.
	 * Add the new label to the generic label change spec for this
	 * domain. Search for an existing one first.
	 */
	found = 1;
	for (lp = label_root; lp != NULL; lp = lp->l_next) {
	    if (lp->old_type != PM_LABEL_DOMAIN)
		continue;
	    if (lp->old_id != domain)
		continue;
	    if (lp->old_label == NULL)
		break;
	}

	/* Create one if none exists. */
	if (lp == NULL)
	    lp = create_label(PM_LABEL_DOMAIN, domain, 0, NULL, NULL);

	/* Add the new label to the label change spec. */
	if ((sts = __pmAddLabels(&lp->new_labels, buf, PM_LABEL_DOMAIN)) < 0) {
	    pmsprintf(mess, sizeof(mess),
		      "Unable to add new domain label %s: %s",
		      buf, pmErrStr(sts));
	    yyerror(mess);
	}
	lp->new_labels->inst = 0;
	lp->flags |= LABEL_NEW;

	/* We only need to find one metric in the specified domain. */
	break;
    }

    /* Did we find any clusters matching the spec? */
    if (! found) {
	pmsprintf(mess, sizeof(mess),
		  "No matching domain for new label %s", buf);
	yywarn(mess);
    }
}

void
new_cluster_label(int cluster)
{
    labelspec_t		*lp;
    int			sts;
    int			found = 0;
    __pmContext		*ctxp;
    __pmHashCtl		*hcp;
    __pmHashNode	*node;
    char		buf[PM_MAXLABELJSONLEN] = "";

    /*
     * Ignore the change specs which were previously identified and instead
     * search the metadata for metrics in the given domain.
     * Create or re-use the change record for each one found. 
     */
    deactivate_labels();

    ctxp = __pmHandleToPtr(pmWhichContext());
    assert(ctxp != NULL);
    /*
     * Note: This application is single threaded, and once we have ctxp
     *	     the associated __pmContext will not move and will only be
     *	     accessed or modified synchronously either here or in libpcp.
     *	     We unlock the context so that it can be locked as required
     *	     within libpcp.
     */
    PM_UNLOCK(ctxp->c_lock);

    /* Prepare the JSON for the new label. */
    pmsprintf(buf, sizeof(buf), "{%s:%s}",
	      current_label_name, current_label_value);

    hcp = &ctxp->c_archctl->ac_log->l_hashpmid;
    for (node = __pmHashWalk(hcp, PM_HASH_WALK_START);
	 node != NULL;
	 node = __pmHashWalk(hcp, PM_HASH_WALK_NEXT)) {
	if (pmID_domain(node->key) != pmID_domain(cluster))
	    continue;
	if (! current_star_metric && 
	    pmID_cluster(node->key) != pmID_cluster(cluster))
	    continue;

	/*
	 * A metric in this cluster exists.
	 * Add the new label to the generic label change spec for the
	 * identified cluster. Search for an existing one first.
	 */
	found = 1;
	for (lp = label_root; lp != NULL; lp = lp->l_next) {
	    if (lp->old_type != PM_LABEL_CLUSTER)
		continue;
	    if (pmID_domain(lp->old_id) != pmID_domain((pmID)(node->key)))
		continue;
	    if (pmID_cluster(lp->old_id) != pmID_cluster((pmID)(node->key)))
		continue;
	    if (lp->old_label == NULL)
		break;
	}

	if (lp == NULL) {
	    pmID current_cluster =
		pmID_build(pmID_domain(node->key), pmID_cluster(node->key), 0);
	    lp = create_label(PM_LABEL_CLUSTER, current_cluster, 0, NULL, NULL);
	}

	/* Add the new label to the label change spec. */
	if ((sts = __pmAddLabels(&lp->new_labels, buf, PM_LABEL_CLUSTER)) < 0) {
	    pmsprintf(mess, sizeof(mess),
		      "Unable to add new cluster label %s: %s",
		      buf, pmErrStr(sts));
	    yyerror(mess);
	}
	lp->new_labels->inst = 0;
	lp->flags |= LABEL_NEW;

	/* Do we need to look for more clusters? */
	if (! current_star_metric)
	    break;
    }

    /* Did we find any clusters matching the spec? */
    if (! found) {
	pmsprintf(mess, sizeof(mess),
		  "No matching cluster for new label %s", buf);
	yywarn(mess);
    }
}

void
new_item_label(int item)
{
    labelspec_t		*lp;
    int			sts;
    int			found = 0;
    __pmContext		*ctxp;
    __pmHashCtl		*hcp;
    __pmHashNode	*node;
    char		buf[PM_MAXLABELJSONLEN] = "";

    /*
     * Ignore the change specs which were previously identified and instead
     * search the metadata for metrics in the given domain.
     * Create or re-use the change record for each one found. 
     */
    deactivate_labels();

    ctxp = __pmHandleToPtr(pmWhichContext());
    assert(ctxp != NULL);
    /*
     * Note: This application is single threaded, and once we have ctxp
     *	     the associated __pmContext will not move and will only be
     *	     accessed or modified synchronously either here or in libpcp.
     *	     We unlock the context so that it can be locked as required
     *	     within libpcp.
     */
    PM_UNLOCK(ctxp->c_lock);

    /* Prepare the JSON for the new label. */
    pmsprintf(buf, sizeof(buf), "{%s:%s}",
	      current_label_name, current_label_value);

    hcp = &ctxp->c_archctl->ac_log->l_hashpmid;
    for (node = __pmHashWalk(hcp, PM_HASH_WALK_START);
	 node != NULL;
	 node = __pmHashWalk(hcp, PM_HASH_WALK_NEXT)) {
	if (pmID_domain(node->key) != pmID_domain(item))
	    continue;
	if (current_star_metric < 2) {
	    if (pmID_cluster(node->key) != pmID_cluster(item))
		continue;
	    if (! current_star_metric && (pmID)(node->key) != (pmID)item)
		continue;
	}

	/*
	 * A metric with this pmID exists.
	 * Add the new label to the generic label change spec for the
	 * identified item. Search for an existing one first.
	 */
	found = 1;
	for (lp = label_root; lp != NULL; lp = lp->l_next) {
	    if (lp->old_type != PM_LABEL_ITEM)
		continue;
	    if ((pmID)(lp->old_id) != (pmID)(node->key))
		continue;
	    if (lp->old_label == NULL)
		break;
	}

	if (lp == NULL)
	    lp = create_label(PM_LABEL_ITEM, (pmID)node->key, 0, NULL, NULL);

	/* Add the new label to the label change spec. */
	if ((sts = __pmAddLabels(&lp->new_labels, buf, PM_LABEL_ITEM)) < 0) {
	    pmsprintf(mess, sizeof(mess),
		      "Unable to add new metric item label %s: %s",
		      buf, pmErrStr(sts));
	    yyerror(mess);
	}
	lp->new_labels->inst = 0;
	lp->flags |= LABEL_NEW;

	/* Do we need to look for more items? */
	if (! current_star_metric)
	    break;
    }

    /* Did we find any items matching the spec? */
    if (! found) {
	pmsprintf(mess, sizeof(mess),
		  "No matching metric for new label %s", buf);
	yywarn(mess);
    }
}

void
new_indom_label(int indom)
{
    labelspec_t		*lp;
    int			sts;
    int			found = 0;
    __pmContext		*ctxp;
    __pmHashCtl		*hcp;
    __pmHashNode	*node;
    char		buf[PM_MAXLABELJSONLEN] = "";

    /*
     * Ignore the change specs which were previously identified and instead
     * search the metadata for metrics in the given domain.
     * Create or re-use the change record for each one found. 
     */
    deactivate_labels();

    ctxp = __pmHandleToPtr(pmWhichContext());
    assert(ctxp != NULL);
    /*
     * Note: This application is single threaded, and once we have ctxp
     *	     the associated __pmContext will not move and will only be
     *	     accessed or modified synchronously either here or in libpcp.
     *	     We unlock the context so that it can be locked as required
     *	     within libpcp.
     */
    PM_UNLOCK(ctxp->c_lock);

    /* Prepare the JSON for the new label. */
    pmsprintf(buf, sizeof(buf), "{%s:%s}",
	      current_label_name, current_label_value);

    hcp = &ctxp->c_archctl->ac_log->l_hashindom;
    for (node = __pmHashWalk(hcp, PM_HASH_WALK_START);
	 node != NULL;
	 node = __pmHashWalk(hcp, PM_HASH_WALK_NEXT)) {
	if (pmInDom_domain(node->key) != pmInDom_domain(indom))
	    continue;
	if (! current_star_indom && 
	    pmInDom_serial(node->key) != pmInDom_serial(indom))
	    continue;

	/*
	 * A metric in this indom exists.
	 * Add the new label to the generic label change spec for the
	 * identified indom. Search for an existing one first.
	 */
	found = 1;
	for (lp = label_root; lp != NULL; lp = lp->l_next) {
	    if (lp->old_type != PM_LABEL_INDOM)
		continue;
	    if (pmInDom_domain(lp->old_id) != pmInDom_domain((pmInDom)(node->key)))
		continue;
	    if (pmInDom_serial(lp->old_id) != pmInDom_serial((pmInDom)(node->key)))
		continue;
	    if (lp->old_instance != -1)
		continue;
	    if (lp->old_label == NULL)
		break;
	}

	if (lp == NULL) {
	    pmInDom current_indom =
		pmInDom_build(pmInDom_domain(node->key), pmInDom_serial(node->key));
	    lp = create_label(PM_LABEL_INDOM, current_indom, 0, NULL, NULL);
	}

	/* Add the new label to the label change spec. */
	if ((sts = __pmAddLabels(&lp->new_labels, buf, PM_LABEL_INDOM)) < 0) {
	    pmsprintf(mess, sizeof(mess),
		      "Unable to add new indom label %s: %s",
		      buf, pmErrStr(sts));
	    yyerror(mess);
	}
	lp->new_labels->inst = 0;
	lp->flags |= LABEL_NEW;

	/* Do we need to look for more indoms? */
	if (! current_star_indom)
	    break;
    }

    /* Did we find any indoms matching the spec? */
    if (! found) {
	pmsprintf(mess, sizeof(mess),
		  "No matching indom for new label %s", buf);
	yywarn(mess);
    }
}

void
new_indom_instance_label(int indom)
{
    labelspec_t		*lp;
    int			sts;
    int			found = 0;
    __pmContext		*ctxp;
    __pmHashCtl		*hcp;
    __pmHashNode	*node;
    __pmLogInDom	*idp;
    char		buf[PM_MAXLABELJSONLEN] = "";

    /*
     * Ignore the change specs which were previously identified and instead
     * search the metadata for metrics in the given domain.
     * Create or re-use the change record for each one found. 
     */
    deactivate_labels();

    ctxp = __pmHandleToPtr(pmWhichContext());
    assert(ctxp != NULL);
    /*
     * Note: This application is single threaded, and once we have ctxp
     *	     the associated __pmContext will not move and will only be
     *	     accessed or modified synchronously either here or in libpcp.
     *	     We unlock the context so that it can be locked as required
     *	     within libpcp.
     */
    PM_UNLOCK(ctxp->c_lock);

    /* Prepare the JSON for the new label. */
    pmsprintf(buf, sizeof(buf), "{%s:%s}",
	      current_label_name, current_label_value);

    hcp = &ctxp->c_archctl->ac_log->l_hashindom;
    for (node = __pmHashWalk(hcp, PM_HASH_WALK_START);
	 node != NULL;
	 node = __pmHashWalk(hcp, PM_HASH_WALK_NEXT)) {
	if (pmInDom_domain(node->key) != pmInDom_domain(indom))
	    continue;
	if (! current_star_indom && 
	    pmInDom_serial(node->key) != pmInDom_serial(indom))
	    continue;

	/*
	 * A metric in this indom exists.
	 * Add the new label to the generic label change specs for the
	 * identified indom instances. Search for existing ones first.
	 */
	for (idp = (__pmLogInDom *)node->data; idp != NULL; idp = idp->next) {
	    int indom_ix;
	    for (indom_ix = 0; indom_ix < idp->numinst; ++indom_ix) {
		int instance = idp->instlist[indom_ix];
		if (current_label_instance != -1 && instance != current_label_instance)
		    continue;
		found = 1;
		for (lp = label_root; lp != NULL; lp = lp->l_next) {
		    if (lp->old_type != PM_LABEL_INSTANCES)
			continue;
		    if (pmInDom_domain(lp->old_id) != pmInDom_domain((pmInDom)(node->key)))
			continue;
		    if (pmInDom_serial(lp->old_id) != pmInDom_serial((pmInDom)(node->key)))
			continue;
		    if (lp->old_instance != instance)
			continue;
		    if (lp->old_label == NULL)
			break;
		}

		if (lp == NULL) {
		    pmInDom current_indom =
			pmInDom_build(pmInDom_domain(node->key), pmInDom_serial(node->key));
		    lp = create_label(PM_LABEL_INSTANCES, current_indom,
				      instance, NULL, NULL);
		}

		/* Add the new label to the label change spec. */
		if ((sts = __pmAddLabels(&lp->new_labels, buf, PM_LABEL_INSTANCES)) < 0) {
		    pmsprintf(mess, sizeof(mess),
			      "Unable to add new indom instance label %s: %s",
			      buf, pmErrStr(sts));
		    yyerror(mess);
		}
		lp->new_labels->inst = instance;
		lp->flags |= LABEL_NEW;
	    }
	}

	/* Do we need to look for more indoms? */
	if (! current_star_indom)
	    break;
    }

    /* Did we find any indom instances matching the spec? */
    if (! found) {
	pmsprintf(mess, sizeof(mess),
		  "No matching indom instance for new label %s", buf);
	yywarn(mess);
    }
}


#line 912 "gram.tab.c" /* yacc.c:339  */

# ifndef YY_NULLPTR
#  if defined __cplusplus && 201103L <= __cplusplus
#   define YY_NULLPTR nullptr
#  else
#   define YY_NULLPTR 0
#  endif
# endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

/* In a future release of Bison, this section will be replaced
   by #include "gram.tab.h".  */
#ifndef YY_YY_GRAM_TAB_H_INCLUDED
# define YY_YY_GRAM_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token type.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    TOK_LBRACE = 258,
    TOK_RBRACE = 259,
    TOK_PLUS = 260,
    TOK_MINUS = 261,
    TOK_COLON = 262,
    TOK_COMMA = 263,
    TOK_ASSIGN = 264,
    TOK_GLOBAL = 265,
    TOK_INDOM = 266,
    TOK_DUPLICATE = 267,
    TOK_METRIC = 268,
    TOK_HOSTNAME = 269,
    TOK_TZ = 270,
    TOK_TIME = 271,
    TOK_NAME = 272,
    TOK_INST = 273,
    TOK_INAME = 274,
    TOK_DELETE = 275,
    TOK_PMID = 276,
    TOK_NULL_INT = 277,
    TOK_TYPE = 278,
    TOK_IF = 279,
    TOK_SEM = 280,
    TOK_UNITS = 281,
    TOK_OUTPUT = 282,
    TOK_RESCALE = 283,
    TOK_TEXT = 284,
    TOK_ONELINE = 285,
    TOK_HELP = 286,
    TOK_ALL = 287,
    TOK_LABEL = 288,
    TOK_CONTEXT = 289,
    TOK_LABEL_STAR = 290,
    TOK_DOMAIN = 291,
    TOK_CLUSTER = 292,
    TOK_ITEM = 293,
    TOK_INSTANCES = 294,
    TOK_INSTANCE = 295,
    TOK_NEW = 296,
    TOK_VALUE = 297,
    TOK_GNAME = 298,
    TOK_NUMBER = 299,
    TOK_STRING = 300,
    TOK_NL_STRING = 301,
    TOK_HNAME = 302,
    TOK_FLOAT = 303,
    TOK_JSON_STRING = 304,
    TOK_JSON_NUMBER = 305,
    TOK_JSON_TRUE = 306,
    TOK_JSON_FALSE = 307,
    TOK_JSON_NULL = 308,
    TOK_INDOM_STAR = 309,
    TOK_PMID_INT = 310,
    TOK_PMID_STAR = 311,
    TOK_TYPE_NAME = 312,
    TOK_SEM_NAME = 313,
    TOK_SPACE_NAME = 314,
    TOK_TIME_NAME = 315,
    TOK_COUNT_NAME = 316,
    TOK_OUTPUT_TYPE = 317
  };
#endif
/* Tokens.  */
#define TOK_LBRACE 258
#define TOK_RBRACE 259
#define TOK_PLUS 260
#define TOK_MINUS 261
#define TOK_COLON 262
#define TOK_COMMA 263
#define TOK_ASSIGN 264
#define TOK_GLOBAL 265
#define TOK_INDOM 266
#define TOK_DUPLICATE 267
#define TOK_METRIC 268
#define TOK_HOSTNAME 269
#define TOK_TZ 270
#define TOK_TIME 271
#define TOK_NAME 272
#define TOK_INST 273
#define TOK_INAME 274
#define TOK_DELETE 275
#define TOK_PMID 276
#define TOK_NULL_INT 277
#define TOK_TYPE 278
#define TOK_IF 279
#define TOK_SEM 280
#define TOK_UNITS 281
#define TOK_OUTPUT 282
#define TOK_RESCALE 283
#define TOK_TEXT 284
#define TOK_ONELINE 285
#define TOK_HELP 286
#define TOK_ALL 287
#define TOK_LABEL 288
#define TOK_CONTEXT 289
#define TOK_LABEL_STAR 290
#define TOK_DOMAIN 291
#define TOK_CLUSTER 292
#define TOK_ITEM 293
#define TOK_INSTANCES 294
#define TOK_INSTANCE 295
#define TOK_NEW 296
#define TOK_VALUE 297
#define TOK_GNAME 298
#define TOK_NUMBER 299
#define TOK_STRING 300
#define TOK_NL_STRING 301
#define TOK_HNAME 302
#define TOK_FLOAT 303
#define TOK_JSON_STRING 304
#define TOK_JSON_NUMBER 305
#define TOK_JSON_TRUE 306
#define TOK_JSON_FALSE 307
#define TOK_JSON_NULL 308
#define TOK_INDOM_STAR 309
#define TOK_PMID_INT 310
#define TOK_PMID_STAR 311
#define TOK_TYPE_NAME 312
#define TOK_SEM_NAME 313
#define TOK_SPACE_NAME 314
#define TOK_TIME_NAME 315
#define TOK_COUNT_NAME 316
#define TOK_OUTPUT_TYPE 317

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED

union YYSTYPE
{
#line 863 "gram.y" /* yacc.c:355  */

    char		*str;
    int			ival;
    double		dval;
    pmInDom		indom;
    pmID		pmid;

#line 1084 "gram.tab.c" /* yacc.c:355  */
};

typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE yylval;

int yyparse (void);

#endif /* !YY_YY_GRAM_TAB_H_INCLUDED  */

/* Copy the second part of user declarations.  */

#line 1101 "gram.tab.c" /* yacc.c:358  */

#ifdef short
# undef short
#endif

#ifdef YYTYPE_UINT8
typedef YYTYPE_UINT8 yytype_uint8;
#else
typedef unsigned char yytype_uint8;
#endif

#ifdef YYTYPE_INT8
typedef YYTYPE_INT8 yytype_int8;
#else
typedef signed char yytype_int8;
#endif

#ifdef YYTYPE_UINT16
typedef YYTYPE_UINT16 yytype_uint16;
#else
typedef unsigned short int yytype_uint16;
#endif

#ifdef YYTYPE_INT16
typedef YYTYPE_INT16 yytype_int16;
#else
typedef short int yytype_int16;
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif ! defined YYSIZE_T
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned int
# endif
#endif

#define YYSIZE_MAXIMUM ((YYSIZE_T) -1)

#ifndef YY_
# if defined YYENABLE_NLS && YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(Msgid) Msgid
# endif
#endif

#ifndef YY_ATTRIBUTE
# if (defined __GNUC__                                               \
      && (2 < __GNUC__ || (__GNUC__ == 2 && 96 <= __GNUC_MINOR__)))  \
     || defined __SUNPRO_C && 0x5110 <= __SUNPRO_C
#  define YY_ATTRIBUTE(Spec) __attribute__(Spec)
# else
#  define YY_ATTRIBUTE(Spec) /* empty */
# endif
#endif

#ifndef YY_ATTRIBUTE_PURE
# define YY_ATTRIBUTE_PURE   YY_ATTRIBUTE ((__pure__))
#endif

#ifndef YY_ATTRIBUTE_UNUSED
# define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
#endif

#if !defined _Noreturn \
     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
# if defined _MSC_VER && 1200 <= _MSC_VER
#  define _Noreturn __declspec (noreturn)
# else
#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YYUSE(E) ((void) (E))
#else
# define YYUSE(E) /* empty */
#endif

#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
/* Suppress an incorrect diagnostic about yylval being uninitialized.  */
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
    _Pragma ("GCC diagnostic push") \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")\
    _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
# define YY_IGNORE_MAYBE_UNINITIALIZED_END \
    _Pragma ("GCC diagnostic pop")
#else
# define YY_INITIAL_VALUE(Value) Value
#endif
#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_END
#endif
#ifndef YY_INITIAL_VALUE
# define YY_INITIAL_VALUE(Value) /* Nothing. */
#endif


#if ! defined yyoverflow || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
#     ifndef EXIT_SUCCESS
#      define EXIT_SUCCESS 0
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's 'empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined EXIT_SUCCESS \
       && ! ((defined YYMALLOC || defined malloc) \
             && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef EXIT_SUCCESS
#    define EXIT_SUCCESS 0
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined EXIT_SUCCESS
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined EXIT_SUCCESS
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* ! defined yyoverflow || YYERROR_VERBOSE */


#if (! defined yyoverflow \
     && (! defined __cplusplus \
         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yytype_int16 yyss_alloc;
  YYSTYPE yyvs_alloc;
};

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (yytype_int16) + sizeof (YYSTYPE)) \
      + YYSTACK_GAP_MAXIMUM)

# define YYCOPY_NEEDED 1

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack_alloc, Stack)                           \
    do                                                                  \
      {                                                                 \
        YYSIZE_T yynewbytes;                                            \
        YYCOPY (&yyptr->Stack_alloc, Stack, yysize);                    \
        Stack = &yyptr->Stack_alloc;                                    \
        yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
        yyptr += yynewbytes / sizeof (*yyptr);                          \
      }                                                                 \
    while (0)

#endif

#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
/* Copy COUNT objects from SRC to DST.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(Dst, Src, Count) \
      __builtin_memcpy (Dst, Src, (Count) * sizeof (*(Src)))
#  else
#   define YYCOPY(Dst, Src, Count)              \
      do                                        \
        {                                       \
          YYSIZE_T yyi;                         \
          for (yyi = 0; yyi < (Count); yyi++)   \
            (Dst)[yyi] = (Src)[yyi];            \
        }                                       \
      while (0)
#  endif
# endif
#endif /* !YYCOPY_NEEDED */

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  41
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   311

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  63
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  87
/* YYNRULES -- Number of rules.  */
#define YYNRULES  231
/* YYNSTATES -- Number of states.  */
#define YYNSTATES  343

/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
   by yylex, with out-of-bounds checking.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   317

#define YYTRANSLATE(YYX)                                                \
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex, without out-of-bounds checking.  */
static const yytype_uint8 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
      55,    56,    57,    58,    59,    60,    61,    62
};

#if YYDEBUG
  /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
static const yytype_uint16 yyrline[] =
{
       0,   928,   928,   931,   932,   935,   936,   937,   938,   939,
     942,   943,   946,   947,   950,   969,   988,  1004,  1009,  1014,
    1019,  1024,  1029,  1042,  1043,  1044,  1045,  1048,  1053,  1058,
    1065,  1072,  1079,  1080,  1081,  1084,  1097,  1109,  1122,  1134,
    1143,  1155,  1154,  1187,  1194,  1216,  1230,  1231,  1234,  1235,
    1238,  1263,  1273,  1282,  1290,  1298,  1303,  1308,  1313,  1318,
    1323,  1328,  1333,  1340,  1341,  1345,  1344,  1387,  1394,  1395,
    1413,  1441,  1471,  1472,  1475,  1476,  1479,  1503,  1527,  1555,
    1586,  1660,  1677,  1723,  1730,  1735,  1740,  1745,  1750,  1755,
    1760,  1765,  1770,  1775,  1780,  1787,  1788,  1794,  1800,  1806,
    1810,  1815,  1818,  1820,  1823,  1826,  1827,  1831,  1830,  1930,
    1933,  1936,  1938,  1942,  1944,  1946,  1950,  1952,  1960,  1961,
    1964,  1971,  2000,  2049,  2051,  2056,  2055,  2148,  2150,  2158,
    2159,  2162,  2169,  2198,  2226,  2229,  2230,  2231,  2232,  2233,
    2234,  2238,  2237,  2292,  2294,  2297,  2303,  2305,  2312,  2314,
    2317,  2320,  2322,  2324,  2326,  2328,  2332,  2337,  2339,  2344,
    2348,  2350,  2355,  2356,  2359,  2366,  2390,  2414,  2419,  2435,
    2434,  2494,  2514,  2516,  2521,  2522,  2525,  2532,  2558,  2582,
    2606,  2613,  2612,  2691,  2714,  2734,  2736,  2741,  2742,  2745,
    2752,  2778,  2802,  2826,  2833,  2832,  2922,  2924,  2929,  2930,
    2933,  2940,  2968,  2992,  3016,  3023,  3022,  3105,  3107,  3112,
    3113,  3116,  3123,  3149,  3173,  3197,  3204,  3203,  3288,  3293,
    3298,  3303,  3310,  3312,  3317,  3318,  3321,  3328,  3354,  3379,
    3403,  3427
};
#endif

#if YYDEBUG || YYERROR_VERBOSE || 0
/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "TOK_LBRACE", "TOK_RBRACE", "TOK_PLUS",
  "TOK_MINUS", "TOK_COLON", "TOK_COMMA", "TOK_ASSIGN", "TOK_GLOBAL",
  "TOK_INDOM", "TOK_DUPLICATE", "TOK_METRIC", "TOK_HOSTNAME", "TOK_TZ",
  "TOK_TIME", "TOK_NAME", "TOK_INST", "TOK_INAME", "TOK_DELETE",
  "TOK_PMID", "TOK_NULL_INT", "TOK_TYPE", "TOK_IF", "TOK_SEM", "TOK_UNITS",
  "TOK_OUTPUT", "TOK_RESCALE", "TOK_TEXT", "TOK_ONELINE", "TOK_HELP",
  "TOK_ALL", "TOK_LABEL", "TOK_CONTEXT", "TOK_LABEL_STAR", "TOK_DOMAIN",
  "TOK_CLUSTER", "TOK_ITEM", "TOK_INSTANCES", "TOK_INSTANCE", "TOK_NEW",
  "TOK_VALUE", "TOK_GNAME", "TOK_NUMBER", "TOK_STRING", "TOK_NL_STRING",
  "TOK_HNAME", "TOK_FLOAT", "TOK_JSON_STRING", "TOK_JSON_NUMBER",
  "TOK_JSON_TRUE", "TOK_JSON_FALSE", "TOK_JSON_NULL", "TOK_INDOM_STAR",
  "TOK_PMID_INT", "TOK_PMID_STAR", "TOK_TYPE_NAME", "TOK_SEM_NAME",
  "TOK_SPACE_NAME", "TOK_TIME_NAME", "TOK_COUNT_NAME", "TOK_OUTPUT_TYPE",
  "$accept", "config", "speclist", "spec", "globalspec", "globaloptlist",
  "globalopt", "hname", "signnumber", "number", "float", "signtime",
  "time", "indomspec", "$@1", "indom_int", "optindomopt", "indomoptlist",
  "indomopt", "duplicateopt", "metricspec", "$@2", "pmid_or_name",
  "pmid_int", "optmetricoptlist", "metricoptlist", "metricopt",
  "null_or_indom", "pick", "rescaleopt", "textspec",
  "textmetricorindomspec", "textmetricspec", "$@3", "opttexttypes",
  "texttypes", "texttype", "opttextmetricoptlist", "textmetricoptlist",
  "textmetricopt", "textstring", "textindomspec", "$@4",
  "opttextindomoptlist", "textindomoptlist", "textindomopt", "labelspec",
  "labelcontextormetricorindomspec", "labelcontextspec", "$@5",
  "optlabeldetails", "jsonname", "optlabelvalue", "jsonvalue",
  "jsonnumber", "optlabelcontextoptlist", "labelcontextoptlist",
  "labelcontextopt", "newlabelspec", "labeldomainspec", "$@6",
  "pmid_domain", "optlabeldomainoptlist", "labeldomainoptlist",
  "labeldomainopt", "labelclusterspec", "$@7", "pmid_cluster",
  "optlabelclusteroptlist", "labelclusteroptlist", "labelclusteropt",
  "labelitemspec", "$@8", "optlabelitemoptlist", "labelitemoptlist",
  "labelitemopt", "labelindomspec", "$@9", "optlabelindomoptlist",
  "labelindomoptlist", "labelindomopt", "labelinstancesspec", "$@10",
  "optinstancelabeldetails", "optlabelinstancesoptlist",
  "labelinstancesoptlist", "labelinstancesopt", YY_NULLPTR
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[NUM] -- (External) token number corresponding to the
   (internal) symbol number NUM (which must be that of a token).  */
static const yytype_uint16 yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   286,   287,   288,   289,   290,   291,   292,   293,   294,
     295,   296,   297,   298,   299,   300,   301,   302,   303,   304,
     305,   306,   307,   308,   309,   310,   311,   312,   313,   314,
     315,   316,   317
};
# endif

#define YYPACT_NINF -254

#define yypact_value_is_default(Yystate) \
  (!!((Yystate) == (-254)))

#define YYTABLE_NINF -65

#define yytable_value_is_error(Yytable_value) \
  0

  /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
     STATE-NUM.  */
static const yytype_int16 yypact[] =
{
     113,     9,    47,    19,    38,    77,    39,  -254,   113,  -254,
    -254,  -254,  -254,  -254,   121,  -254,  -254,  -254,  -254,  -254,
    -254,  -254,  -254,    47,    19,  -254,  -254,  -254,    47,    -4,
       0,   106,    19,    47,  -254,  -254,  -254,  -254,  -254,  -254,
    -254,  -254,  -254,  -254,    82,    91,   108,   118,   184,   124,
     131,   171,   171,    -4,     3,  -254,  -254,  -254,     3,  -254,
      -4,  -254,  -254,    -4,    -4,    84,   149,   102,    37,  -254,
    -254,   160,   163,  -254,  -254,  -254,  -254,  -254,   171,  -254,
    -254,    88,  -254,  -254,  -254,  -254,  -254,  -254,  -254,  -254,
    -254,  -254,   146,  -254,  -254,  -254,  -254,    -4,    -4,     3,
    -254,  -254,  -254,  -254,  -254,  -254,  -254,   137,   137,  -254,
    -254,   156,  -254,  -254,  -254,   166,   138,   127,   191,  -254,
     160,   199,   200,  -254,   201,    83,   202,   203,   209,  -254,
     163,   211,  -254,   212,   213,  -254,  -254,   128,   214,   215,
     216,  -254,  -254,  -254,   217,  -254,  -254,   137,    18,   218,
     219,  -254,  -254,    28,   178,    54,   165,   167,   168,    23,
    -254,  -254,     4,    64,    79,  -254,   220,   145,   221,   227,
    -254,   128,  -254,   123,   125,   135,   111,   225,  -254,  -254,
      47,    20,     1,  -254,  -254,   196,  -254,  -254,  -254,   224,
    -254,   181,   190,  -254,   228,   226,  -254,   229,   233,  -254,
       4,   230,  -254,   231,   237,  -254,    64,   234,  -254,   235,
     236,  -254,   243,  -254,    79,   145,    53,    53,  -254,  -254,
    -254,   239,   240,   242,  -254,   248,  -254,   123,  -254,   245,
     246,   247,  -254,   253,  -254,   125,  -254,   250,   251,   252,
    -254,   258,  -254,   135,  -254,   255,   256,   257,   260,  -254,
     263,  -254,   111,   137,  -254,  -254,  -254,  -254,  -254,    -5,
    -254,   222,  -254,  -254,    23,    47,   159,  -254,  -254,    54,
     159,  -254,  -254,    47,   145,    53,  -254,  -254,  -254,  -254,
    -254,   145,   232,    53,  -254,  -254,   145,   106,    53,  -254,
    -254,   145,    54,    53,  -254,  -254,   145,    47,   238,    53,
    -254,  -254,  -254,  -254,   138,   241,  -254,  -254,   262,  -254,
    -254,  -254,  -254,  -254,  -254,  -254,  -254,  -254,  -254,  -254,
    -254,  -254,  -254,  -254,  -254,  -254,  -254,  -254,  -254,  -254,
    -254,  -254,  -254,    23,   264,   244,   265,   223,   267,   210,
     249,  -254,  -254
};

  /* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
     Performed when YYTABLE does not specify something else to do.  Zero
     means the default is an error.  */
static const yytype_uint8 yydefact[] =
{
       0,     0,    43,    67,     0,     0,     0,     2,     3,     5,
       6,     7,     8,     9,     0,    44,    45,    41,    69,    70,
      71,    65,    68,     0,     0,   104,   105,   106,     0,   145,
       0,     0,     0,     0,   134,   135,   136,   137,   138,   139,
     140,     1,     4,    11,    18,    20,    22,     0,    12,     0,
       0,   110,   110,   145,   150,   147,   146,   141,   150,   171,
     145,   183,   184,   145,   145,   221,    17,    19,    21,    10,
      13,    47,    73,   115,   114,   113,   125,   109,   111,   107,
     205,     0,   149,   157,   159,   153,   154,   155,   151,   144,
     148,   152,     0,   143,   169,   181,   194,   145,   145,   150,
     216,    24,    25,    23,    26,    14,    15,     0,     0,    30,
      31,    40,    39,    16,    34,    56,    62,    59,     0,    46,
      48,     0,     0,    83,     0,     0,     0,     0,     0,    72,
      74,     0,   112,     0,     0,   156,   158,   161,     0,     0,
       0,   220,   219,   218,     0,    32,    33,     0,    55,    61,
      58,    42,    49,    89,    85,    84,    86,    87,    90,    91,
      66,    75,   128,   117,   208,   164,     0,     0,     0,     0,
     160,   162,   167,   173,   186,   197,   223,    38,    37,    63,
       0,    60,    57,    96,    95,   101,    77,    76,    78,     0,
      81,     0,     0,    29,     0,     0,   131,     0,     0,   127,
     129,     0,   120,     0,     0,   116,   118,     0,   211,     0,
       0,   215,     0,   207,   209,     0,     0,     0,   142,   163,
     176,     0,     0,     0,   180,     0,   172,   174,   189,     0,
       0,     0,   193,     0,   185,   187,   200,     0,     0,     0,
     204,     0,   196,   198,   226,     0,     0,     0,     0,   231,
       0,   222,   224,     0,    50,    54,    53,    52,    51,   100,
      80,    88,    27,    28,     0,     0,     0,   126,   130,     0,
       0,   108,   119,     0,     0,     0,   206,   210,   165,   168,
     166,     0,     0,     0,   170,   175,     0,     0,     0,   182,
     188,     0,     0,     0,   195,   199,     0,     0,     0,     0,
     217,   225,    36,    35,     0,     0,    99,    79,     0,   133,
     123,   124,   132,   122,   121,   212,   213,   214,   178,   177,
     179,   191,   190,   192,   202,   201,   203,   229,   227,   228,
     230,    97,    98,     0,     0,    92,     0,    93,     0,    94,
     103,   102,    82
};

  /* YYPGOTO[NTERM-NUM].  */
static const yytype_int16 yypgoto[] =
{
    -254,  -254,   270,  -254,  -254,   254,  -254,  -254,  -253,  -113,
    -145,  -254,    99,  -254,  -254,   -23,  -254,   161,  -254,  -254,
    -254,  -254,    62,  -151,  -254,   150,  -254,  -254,  -254,  -254,
    -254,  -254,  -254,  -254,   259,   206,  -254,  -254,    81,  -254,
      15,  -254,  -254,  -254,    89,  -254,  -254,  -254,  -254,  -254,
     -37,   -28,   -36,  -210,  -254,  -254,   117,  -254,  -156,  -254,
    -254,  -254,  -254,    63,  -254,  -254,  -254,     5,  -254,    56,
    -254,  -254,  -254,  -254,    50,  -254,  -254,  -254,  -254,    80,
    -254,  -254,  -254,  -254,  -254,    43,  -254
};

  /* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int16 yydefgoto[] =
{
      -1,     6,     7,     8,     9,    47,    48,   105,   194,   111,
     112,   113,   114,    10,    49,    17,   118,   119,   120,   180,
      11,    50,    21,    22,   128,   129,   130,   185,   260,   342,
      12,    25,    26,   133,    76,    77,    78,   204,   205,   206,
     312,    27,   131,   198,   199,   200,    13,    34,    35,    92,
      57,    88,    89,    90,    91,   169,   170,   171,   172,    36,
     138,    60,   225,   226,   227,    37,   139,    63,   233,   234,
     235,    38,   140,   241,   242,   243,    39,   134,   212,   213,
     214,    40,   144,   100,   250,   251,   252
};

  /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
     positive, shift that token.  If negative, reduce the rule whose
     number is the opposite.  If YYTABLE_NINF, syntax error.  */
static const yytype_int16 yytable[] =
{
      51,    58,   178,   149,   187,    53,   279,   280,   211,    81,
      65,   308,    14,   304,   305,   195,    80,   224,   232,   240,
     249,   257,    93,    94,   196,    58,    95,    96,   191,   192,
     179,    54,    58,   197,   177,    58,    58,    99,    82,    41,
     255,    55,   107,   108,    59,    56,   258,    83,    55,    23,
     183,    24,    56,    84,    85,    86,    87,   306,   211,    81,
     141,   142,    18,   143,   109,   317,   -64,   193,   256,    58,
      58,   224,   -64,   320,    19,    20,    15,   201,   323,   232,
     334,   109,    16,   326,   202,   110,    52,   240,    28,   330,
     207,    66,   156,   203,    64,    15,   249,    83,    55,   208,
      67,    16,    56,    84,    85,    86,    87,   157,   303,    19,
      20,    29,   209,    30,    31,    32,    33,    68,   313,    97,
     167,   210,    69,     1,     2,    43,     3,    71,    98,    55,
     184,   244,   135,    56,    72,    44,    45,    46,   136,   216,
     302,   325,     4,   220,   245,   228,     5,   106,   165,   137,
     246,   247,   167,   248,    61,   236,   221,   254,   229,   222,
      62,   166,   230,   147,   167,   223,   167,   231,   237,   167,
     168,   115,   150,   238,   121,   148,   167,   239,   116,   117,
     122,   109,   109,   123,   124,   110,   125,   278,   126,   127,
      55,   331,   101,   102,    56,   151,   103,   104,    44,    45,
      46,    73,    74,    75,   310,   311,   145,   146,   153,   154,
     155,   158,   159,   160,   162,   163,   164,   173,   174,   175,
     176,   186,   188,   259,   189,   262,   190,   181,   182,   215,
     217,   218,   253,   261,   263,   265,   264,   267,   266,   269,
     270,   271,   309,   273,   274,   275,   316,   276,   281,   282,
     315,   283,   284,   318,   286,   287,   288,   289,   321,   291,
     292,   293,   294,   324,   296,   297,   298,   300,   327,   299,
     333,   340,   335,   337,   328,   339,   319,   341,    42,   307,
     161,   152,   329,   338,   132,   314,   332,   272,   219,   268,
     285,   290,   322,   295,   277,   301,     0,     0,     0,     0,
       0,     0,    70,   336,     0,     0,     0,     0,     0,     0,
       0,    79
};

static const yytype_int16 yycheck[] =
{
      23,    29,   147,   116,   155,    28,   216,   217,   164,     6,
      33,   264,     3,    18,    19,    11,    53,   173,   174,   175,
     176,    20,    58,    60,    20,    53,    63,    64,     5,     6,
      12,    35,    60,    29,   147,    63,    64,    65,    35,     0,
      20,    45,     5,     6,    44,    49,    45,    44,    45,    11,
      22,    13,    49,    50,    51,    52,    53,    62,   214,     6,
      97,    98,    43,    99,    44,   275,    48,    44,   181,    97,
      98,   227,    54,   283,    55,    56,    48,    13,   288,   235,
     333,    44,    54,   293,    20,    48,    24,   243,    11,   299,
      11,     9,     9,    29,    32,    48,   252,    44,    45,    20,
       9,    54,    49,    50,    51,    52,    53,    24,   253,    55,
      56,    34,    33,    36,    37,    38,    39,     9,   269,    35,
      41,    42,     4,    10,    11,     4,    13,     3,    44,    45,
     153,    20,    44,    49,     3,    14,    15,    16,    50,   167,
     253,   292,    29,    20,    33,    20,    33,    45,    20,     3,
      39,    40,    41,    42,    48,    20,    33,   180,    33,    36,
      54,    33,    37,     7,    41,    42,    41,    42,    33,    41,
      42,    11,    45,    38,    11,     9,    41,    42,    18,    19,
      17,    44,    44,    20,    21,    48,    23,   215,    25,    26,
      45,   304,    43,    44,    49,     4,    47,    48,    14,    15,
      16,    30,    31,    32,    45,    46,   107,   108,     9,     9,
       9,     9,     9,     4,     3,     3,     3,     3,     3,     3,
       3,    43,    57,    27,    57,    44,    58,     9,     9,     9,
       9,     4,     7,     9,    44,     9,     8,     4,     9,     9,
       9,     4,   265,     9,     9,     9,   274,     4,     9,     9,
     273,     9,     4,   281,     9,     9,     9,     4,   286,     9,
       9,     9,     4,   291,     9,     9,     9,     4,   296,     9,
       8,    61,     8,     8,   297,     8,    44,    28,     8,    57,
     130,   120,    44,    60,    78,   270,    45,   206,   171,   200,
     227,   235,   287,   243,   214,   252,    -1,    -1,    -1,    -1,
      -1,    -1,    48,    59,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    52
};

  /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
     symbol of state STATE-NUM.  */
static const yytype_uint8 yystos[] =
{
       0,    10,    11,    13,    29,    33,    64,    65,    66,    67,
      76,    83,    93,   109,     3,    48,    54,    78,    43,    55,
      56,    85,    86,    11,    13,    94,    95,   104,    11,    34,
      36,    37,    38,    39,   110,   111,   122,   128,   134,   139,
     144,     0,    65,     4,    14,    15,    16,    68,    69,    77,
      84,    78,    85,    78,    35,    45,    49,   113,   114,    44,
     124,    48,    54,   130,    85,    78,     9,     9,     9,     4,
      68,     3,     3,    30,    31,    32,    97,    98,    99,    97,
     113,     6,    35,    44,    50,    51,    52,    53,   114,   115,
     116,   117,   112,   115,   113,   113,   113,    35,    44,   114,
     146,    43,    44,    47,    48,    70,    45,     5,     6,    44,
      48,    72,    73,    74,    75,    11,    18,    19,    79,    80,
      81,    11,    17,    20,    21,    23,    25,    26,    87,    88,
      89,   105,    98,    96,   140,    44,    50,     3,   123,   129,
     135,   113,   113,   115,   145,    75,    75,     7,     9,    72,
      45,     4,    80,     9,     9,     9,     9,    24,     9,     9,
       4,    88,     3,     3,     3,    20,    33,    41,    42,   118,
     119,   120,   121,     3,     3,     3,     3,    72,    73,    12,
      82,     9,     9,    22,    78,    90,    43,    86,    57,    57,
      58,     5,     6,    44,    71,    11,    20,    29,   106,   107,
     108,    13,    20,    29,   100,   101,   102,    11,    20,    33,
      42,   121,   141,   142,   143,     9,   114,     9,     4,   119,
      20,    33,    36,    42,   121,   125,   126,   127,    20,    33,
      37,    42,   121,   131,   132,   133,    20,    33,    38,    42,
     121,   136,   137,   138,    20,    33,    39,    40,    42,   121,
     147,   148,   149,     7,    78,    20,    72,    20,    45,    27,
      91,     9,    44,    44,     8,     9,     9,     4,   107,     9,
       9,     4,   101,     9,     9,     9,     4,   142,   114,   116,
     116,     9,     9,     9,     4,   126,     9,     9,     9,     4,
     132,     9,     9,     9,     4,   137,     9,     9,     9,     9,
       4,   148,    72,    73,    18,    19,    62,    57,    71,    78,
      45,    46,   103,    86,   103,    78,   114,   116,   114,    44,
     116,   114,   130,   116,   114,    86,   116,   114,    78,    44,
     116,    72,    45,     8,    71,     8,    59,     8,    60,     8,
      61,    28,    92
};

  /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const yytype_uint8 yyr1[] =
{
       0,    63,    64,    65,    65,    66,    66,    66,    66,    66,
      67,    67,    68,    68,    69,    69,    69,    69,    69,    69,
      69,    69,    69,    70,    70,    70,    70,    71,    71,    71,
      72,    73,    74,    74,    74,    75,    75,    75,    75,    75,
      75,    77,    76,    76,    78,    78,    79,    79,    80,    80,
      81,    81,    81,    81,    81,    81,    81,    81,    81,    81,
      81,    81,    81,    82,    82,    84,    83,    83,    85,    85,
      86,    86,    87,    87,    88,    88,    89,    89,    89,    89,
      89,    89,    89,    89,    89,    89,    89,    89,    89,    89,
      89,    89,    89,    89,    89,    90,    90,    91,    91,    91,
      91,    91,    92,    92,    93,    94,    94,    96,    95,    97,
      97,    98,    98,    99,    99,    99,   100,   100,   101,   101,
     102,   102,   102,   103,   103,   105,   104,   106,   106,   107,
     107,   108,   108,   108,   109,   110,   110,   110,   110,   110,
     110,   112,   111,   113,   113,   113,   114,   114,   115,   115,
     115,   116,   116,   116,   116,   116,   117,   117,   117,   117,
     118,   118,   119,   119,   120,   120,   120,   120,   121,   123,
     122,   124,   125,   125,   126,   126,   127,   127,   127,   127,
     127,   129,   128,   130,   130,   131,   131,   132,   132,   133,
     133,   133,   133,   133,   135,   134,   136,   136,   137,   137,
     138,   138,   138,   138,   138,   140,   139,   141,   141,   142,
     142,   143,   143,   143,   143,   143,   145,   144,   146,   146,
     146,   146,   147,   147,   148,   148,   149,   149,   149,   149,
     149,   149
};

  /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
static const yytype_uint8 yyr2[] =
{
       0,     2,     1,     1,     2,     1,     1,     1,     1,     1,
       4,     3,     1,     2,     3,     3,     3,     2,     1,     2,
       1,     2,     1,     1,     1,     1,     1,     2,     2,     1,
       1,     1,     2,     2,     1,     5,     5,     3,     3,     1,
       1,     0,     6,     1,     1,     1,     1,     0,     1,     2,
       4,     4,     4,     4,     4,     2,     1,     3,     2,     1,
       3,     2,     1,     1,     0,     0,     6,     1,     1,     1,
       1,     1,     1,     0,     1,     2,     3,     3,     3,     5,
       4,     3,    14,     1,     2,     2,     2,     2,     4,     2,
       2,     2,     8,    10,    12,     1,     1,     3,     3,     2,
       1,     0,     1,     0,     2,     1,     1,     0,     7,     1,
       0,     1,     2,     1,     1,     1,     1,     0,     1,     2,
       1,     3,     3,     1,     1,     0,     7,     1,     0,     1,
       2,     1,     3,     3,     2,     1,     1,     1,     1,     1,
       1,     0,     6,     2,     2,     0,     1,     1,     1,     1,
       0,     1,     1,     1,     1,     1,     2,     1,     2,     1,
       1,     0,     1,     2,     1,     3,     3,     1,     3,     0,
       7,     1,     1,     0,     1,     2,     1,     3,     3,     3,
       1,     0,     7,     1,     1,     1,     0,     1,     2,     1,
       3,     3,     3,     1,     0,     7,     1,     0,     1,     2,
       1,     3,     3,     3,     1,     0,     7,     1,     0,     1,
       2,     1,     3,     3,     3,     1,     0,     7,     2,     2,
       2,     0,     1,     0,     1,     2,     1,     3,     3,     3,
       3,     1
};


#define yyerrok         (yyerrstatus = 0)
#define yyclearin       (yychar = YYEMPTY)
#define YYEMPTY         (-2)
#define YYEOF           0

#define YYACCEPT        goto yyacceptlab
#define YYABORT         goto yyabortlab
#define YYERROR         goto yyerrorlab


#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)                                  \
do                                                              \
  if (yychar == YYEMPTY)                                        \
    {                                                           \
      yychar = (Token);                                         \
      yylval = (Value);                                         \
      YYPOPSTACK (yylen);                                       \
      yystate = *yyssp;                                         \
      goto yybackup;                                            \
    }                                                           \
  else                                                          \
    {                                                           \
      yyerror (YY_("syntax error: cannot back up")); \
      YYERROR;                                                  \
    }                                                           \
while (0)

/* Error token number */
#define YYTERROR        1
#define YYERRCODE       256



/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)                        \
do {                                            \
  if (yydebug)                                  \
    YYFPRINTF Args;                             \
} while (0)

/* This macro is provided for backward compatibility. */
#ifndef YY_LOCATION_PRINT
# define YY_LOCATION_PRINT(File, Loc) ((void) 0)
#endif


# define YY_SYMBOL_PRINT(Title, Type, Value, Location)                    \
do {                                                                      \
  if (yydebug)                                                            \
    {                                                                     \
      YYFPRINTF (stderr, "%s ", Title);                                   \
      yy_symbol_print (stderr,                                            \
                  Type, Value); \
      YYFPRINTF (stderr, "\n");                                           \
    }                                                                     \
} while (0)


/*----------------------------------------.
| Print this symbol's value on YYOUTPUT.  |
`----------------------------------------*/

static void
yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
{
  FILE *yyo = yyoutput;
  YYUSE (yyo);
  if (!yyvaluep)
    return;
# ifdef YYPRINT
  if (yytype < YYNTOKENS)
    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# endif
  YYUSE (yytype);
}


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

static void
yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
{
  YYFPRINTF (yyoutput, "%s %s (",
             yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);

  yy_symbol_value_print (yyoutput, yytype, yyvaluep);
  YYFPRINTF (yyoutput, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

static void
yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
{
  YYFPRINTF (stderr, "Stack now");
  for (; yybottom <= yytop; yybottom++)
    {
      int yybot = *yybottom;
      YYFPRINTF (stderr, " %d", yybot);
    }
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)                            \
do {                                                            \
  if (yydebug)                                                  \
    yy_stack_print ((Bottom), (Top));                           \
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

static void
yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
{
  unsigned long int yylno = yyrline[yyrule];
  int yynrhs = yyr2[yyrule];
  int yyi;
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
             yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr,
                       yystos[yyssp[yyi + 1 - yynrhs]],
                       &(yyvsp[(yyi + 1) - (yynrhs)])
                                              );
      YYFPRINTF (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)          \
do {                                    \
  if (yydebug)                          \
    yy_reduce_print (yyssp, yyvsp, Rule); \
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif


#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined __GLIBC__ && defined _STRING_H
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
static YYSIZE_T
yystrlen (const char *yystr)
{
  YYSIZE_T yylen;
  for (yylen = 0; yystr[yylen]; yylen++)
    continue;
  return yylen;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined __GLIBC__ && defined _STRING_H && defined _GNU_SOURCE
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
yystpcpy (char *yydest, const char *yysrc)
{
  char *yyd = yydest;
  const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

# ifndef yytnamerr
/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
   quotes and backslashes, so that it's suitable for yyerror.  The
   heuristic is that double-quoting is unnecessary unless the string
   contains an apostrophe, a comma, or backslash (other than
   backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
   null, do not copy; instead, return the length of what the result
   would have been.  */
static YYSIZE_T
yytnamerr (char *yyres, const char *yystr)
{
  if (*yystr == '"')
    {
      YYSIZE_T yyn = 0;
      char const *yyp = yystr;

      for (;;)
        switch (*++yyp)
          {
          case '\'':
          case ',':
            goto do_not_strip_quotes;

          case '\\':
            if (*++yyp != '\\')
              goto do_not_strip_quotes;
            /* Fall through.  */
          default:
            if (yyres)
              yyres[yyn] = *yyp;
            yyn++;
            break;

          case '"':
            if (yyres)
              yyres[yyn] = '\0';
            return yyn;
          }
    do_not_strip_quotes: ;
    }

  if (! yyres)
    return yystrlen (yystr);

  return yystpcpy (yyres, yystr) - yyres;
}
# endif

/* Copy into *YYMSG, which is of size *YYMSG_ALLOC, an error message
   about the unexpected token YYTOKEN for the state stack whose top is
   YYSSP.

   Return 0 if *YYMSG was successfully written.  Return 1 if *YYMSG is
   not large enough to hold the message.  In that case, also set
   *YYMSG_ALLOC to the required number of bytes.  Return 2 if the
   required number of bytes is too large to store.  */
static int
yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                yytype_int16 *yyssp, int yytoken)
{
  YYSIZE_T yysize0 = yytnamerr (YY_NULLPTR, yytname[yytoken]);
  YYSIZE_T yysize = yysize0;
  enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
  /* Internationalized format string. */
  const char *yyformat = YY_NULLPTR;
  /* Arguments of yyformat. */
  char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
  /* Number of reported tokens (one for the "unexpected", one per
     "expected"). */
  int yycount = 0;

  /* There are many possibilities here to consider:
     - If this state is a consistent state with a default action, then
       the only way this function was invoked is if the default action
       is an error action.  In that case, don't check for expected
       tokens because there are none.
     - The only way there can be no lookahead present (in yychar) is if
       this state is a consistent state with a default action.  Thus,
       detecting the absence of a lookahead is sufficient to determine
       that there is no unexpected or expected token to report.  In that
       case, just report a simple "syntax error".
     - Don't assume there isn't a lookahead just because this state is a
       consistent state with a default action.  There might have been a
       previous inconsistent state, consistent state with a non-default
       action, or user semantic action that manipulated yychar.
     - Of course, the expected token list depends on states to have
       correct lookahead information, and it depends on the parser not
       to perform extra reductions after fetching a lookahead from the
       scanner and before detecting a syntax error.  Thus, state merging
       (from LALR or IELR) and default reductions corrupt the expected
       token list.  However, the list is correct for canonical LR with
       one exception: it will still contain any token that will not be
       accepted due to an error action in a later state.
  */
  if (yytoken != YYEMPTY)
    {
      int yyn = yypact[*yyssp];
      yyarg[yycount++] = yytname[yytoken];
      if (!yypact_value_is_default (yyn))
        {
          /* Start YYX at -YYN if negative to avoid negative indexes in
             YYCHECK.  In other words, skip the first -YYN actions for
             this state because they are default actions.  */
          int yyxbegin = yyn < 0 ? -yyn : 0;
          /* Stay within bounds of both yycheck and yytname.  */
          int yychecklim = YYLAST - yyn + 1;
          int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
          int yyx;

          for (yyx = yyxbegin; yyx < yyxend; ++yyx)
            if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR
                && !yytable_value_is_error (yytable[yyx + yyn]))
              {
                if (yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
                  {
                    yycount = 1;
                    yysize = yysize0;
                    break;
                  }
                yyarg[yycount++] = yytname[yyx];
                {
                  YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
                  if (! (yysize <= yysize1
                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
                    return 2;
                  yysize = yysize1;
                }
              }
        }
    }

  switch (yycount)
    {
# define YYCASE_(N, S)                      \
      case N:                               \
        yyformat = S;                       \
      break
    default: /* Avoid compiler warnings. */
      YYCASE_(0, YY_("syntax error"));
      YYCASE_(1, YY_("syntax error, unexpected %s"));
      YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
      YYCASE_(3, YY_("syntax error, unexpected %s, expecting %s or %s"));
      YYCASE_(4, YY_("syntax error, unexpected %s, expecting %s or %s or %s"));
      YYCASE_(5, YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s"));
# undef YYCASE_
    }

  {
    YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
      return 2;
    yysize = yysize1;
  }

  if (*yymsg_alloc < yysize)
    {
      *yymsg_alloc = 2 * yysize;
      if (! (yysize <= *yymsg_alloc
             && *yymsg_alloc <= YYSTACK_ALLOC_MAXIMUM))
        *yymsg_alloc = YYSTACK_ALLOC_MAXIMUM;
      return 1;
    }

  /* Avoid sprintf, as that infringes on the user's name space.
     Don't have undefined behavior even if the translation
     produced a string with the wrong number of "%s"s.  */
  {
    char *yyp = *yymsg;
    int yyi = 0;
    while ((*yyp = *yyformat) != '\0')
      if (*yyp == '%' && yyformat[1] == 's' && yyi < yycount)
        {
          yyp += yytnamerr (yyp, yyarg[yyi++]);
          yyformat += 2;
        }
      else
        {
          yyp++;
          yyformat++;
        }
  }
  return 0;
}
#endif /* YYERROR_VERBOSE */

/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

static void
yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
{
  YYUSE (yyvaluep);
  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YYUSE (yytype);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}




/* The lookahead symbol.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;
/* Number of syntax errors so far.  */
int yynerrs;


/*----------.
| yyparse.  |
`----------*/

int
yyparse (void)
{
    int yystate;
    /* Number of tokens to shift before error messages enabled.  */
    int yyerrstatus;

    /* The stacks and their tools:
       'yyss': related to states.
       'yyvs': related to semantic values.

       Refer to the stacks through separate pointers, to allow yyoverflow
       to reallocate them elsewhere.  */

    /* The state stack.  */
    yytype_int16 yyssa[YYINITDEPTH];
    yytype_int16 *yyss;
    yytype_int16 *yyssp;

    /* The semantic value stack.  */
    YYSTYPE yyvsa[YYINITDEPTH];
    YYSTYPE *yyvs;
    YYSTYPE *yyvsp;

    YYSIZE_T yystacksize;

  int yyn;
  int yyresult;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken = 0;
  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;

#if YYERROR_VERBOSE
  /* Buffer for error messages, and its allocated size.  */
  char yymsgbuf[128];
  char *yymsg = yymsgbuf;
  YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
#endif

#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))

  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  yyssp = yyss = yyssa;
  yyvsp = yyvs = yyvsa;
  yystacksize = YYINITDEPTH;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY; /* Cause a token to be read.  */
  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
        /* Give user a chance to reallocate the stack.  Use copies of
           these so that the &'s don't force the real ones into
           memory.  */
        YYSTYPE *yyvs1 = yyvs;
        yytype_int16 *yyss1 = yyss;

        /* Each stack pointer address is followed by the size of the
           data in use in that stack, in bytes.  This used to be a
           conditional around just the two extra args, but that might
           be undefined if yyoverflow is a macro.  */
        yyoverflow (YY_("memory exhausted"),
                    &yyss1, yysize * sizeof (*yyssp),
                    &yyvs1, yysize * sizeof (*yyvsp),
                    &yystacksize);

        yyss = yyss1;
        yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyexhaustedlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
        goto yyexhaustedlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
        yystacksize = YYMAXDEPTH;

      {
        yytype_int16 *yyss1 = yyss;
        union yyalloc *yyptr =
          (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
        if (! yyptr)
          goto yyexhaustedlab;
        YYSTACK_RELOCATE (yyss_alloc, yyss);
        YYSTACK_RELOCATE (yyvs_alloc, yyvs);
#  undef YYSTACK_RELOCATE
        if (yyss1 != yyssa)
          YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;

      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
                  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
        YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  if (yystate == YYFINAL)
    YYACCEPT;

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

  /* Do appropriate processing given the current state.  Read a
     lookahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to lookahead token.  */
  yyn = yypact[yystate];
  if (yypact_value_is_default (yyn))
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = yylex ();
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yytable_value_is_error (yyn))
        goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the lookahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);

  /* Discard the shifted token.  */
  yychar = YYEMPTY;

  yystate = yyn;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END

  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     '$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 14:
#line 951 "gram.y" /* yacc.c:1648  */
    {
			if (global.flags & GLOBAL_CHANGE_HOSTNAME) {
			    pmsprintf(mess, sizeof(mess), "Duplicate global hostname clause");
			    yyerror(mess);
			}
			if (strcmp(inarch.label.ll_hostname, (yyvsp[0].str)) == 0) {
			    /* no change ... */
			    if (wflag) {
				pmsprintf(mess, sizeof(mess), "Global hostname (%s): No change", inarch.label.ll_hostname);
				yywarn(mess);
			    }
			}
			else {
			    strncpy(global.hostname, (yyvsp[0].str), sizeof(global.hostname));
			    global.flags |= GLOBAL_CHANGE_HOSTNAME;
			}
			free((yyvsp[0].str));
		    }
#line 2478 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 15:
#line 970 "gram.y" /* yacc.c:1648  */
    {
			if (global.flags & GLOBAL_CHANGE_TZ) {
			    pmsprintf(mess, sizeof(mess), "Duplicate global tz clause");
			    yyerror(mess);
			}
			if (strcmp(inarch.label.ll_tz, (yyvsp[0].str)) == 0) {
			    /* no change ... */
			    if (wflag) {
				pmsprintf(mess, sizeof(mess), "Global timezone (%s): No change", inarch.label.ll_tz);
				yywarn(mess);
			    }
			}
			else {
			    strncpy(global.tz, (yyvsp[0].str), sizeof(global.tz));
			    global.flags |= GLOBAL_CHANGE_TZ;
			}
			free((yyvsp[0].str));
		    }
#line 2501 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 16:
#line 989 "gram.y" /* yacc.c:1648  */
    {
			if (global.flags & GLOBAL_CHANGE_TIME) {
			    pmsprintf(mess, sizeof(mess), "Duplicate global time clause");
			    yyerror(mess);
			}
			if (global.time.tv_sec == 0 && global.time.tv_usec == 0) {
			    /* no change ... */
			    if (wflag) {
				pmsprintf(mess, sizeof(mess), "Global time: No change");
				yywarn(mess);
			    }
			}
			else
			    global.flags |= GLOBAL_CHANGE_TIME;
		    }
#line 2521 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 17:
#line 1005 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting hostname in hostname clause");
			yyerror(mess);
		    }
#line 2530 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 18:
#line 1010 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting -> in hostname clause");
			yyerror(mess);
		    }
#line 2539 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 19:
#line 1015 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting timezone string in tz clause");
			yyerror(mess);
		    }
#line 2548 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 20:
#line 1020 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting -> in tz clause");
			yyerror(mess);
		    }
#line 2557 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 21:
#line 1025 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting delta of the form [+-][HH:[MM:]]SS[.d...] in time clause");
			yyerror(mess);
		    }
#line 2566 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 22:
#line 1030 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting -> in time clause");
			yyerror(mess);
		    }
#line 2575 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 27:
#line 1049 "gram.y" /* yacc.c:1648  */
    {
			(yyval.ival) = atoi((yyvsp[0].str));
			free((yyvsp[0].str));
		    }
#line 2584 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 28:
#line 1054 "gram.y" /* yacc.c:1648  */
    {
			(yyval.ival) = -atoi((yyvsp[0].str));
			free((yyvsp[0].str));
		    }
#line 2593 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 29:
#line 1059 "gram.y" /* yacc.c:1648  */
    {
			(yyval.ival) = atoi((yyvsp[0].str));
			free((yyvsp[0].str));
		    }
#line 2602 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 30:
#line 1066 "gram.y" /* yacc.c:1648  */
    {
			(yyval.ival) = atoi((yyvsp[0].str));
			free((yyvsp[0].str));
		    }
#line 2611 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 31:
#line 1073 "gram.y" /* yacc.c:1648  */
    {
			(yyval.dval) = atof((yyvsp[0].str));
			free((yyvsp[0].str));
		    }
#line 2620 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 33:
#line 1080 "gram.y" /* yacc.c:1648  */
    { global.time.tv_sec = -global.time.tv_sec; }
#line 2626 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 35:
#line 1085 "gram.y" /* yacc.c:1648  */
    { 
			if ((yyvsp[-2].ival) > 59) {
			    pmsprintf(mess, sizeof(mess), "Minutes (%d) in time clause more than 59", (yyvsp[-2].ival));
			    yywarn(mess);
			}
			if ((yyvsp[0].dval) > 59) {
			    pmsprintf(mess, sizeof(mess), "Seconds (%.6f) in time clause more than 59", (yyvsp[0].dval));
			    yywarn(mess);
			}
			global.time.tv_sec = (yyvsp[-4].ival) * 3600 + (yyvsp[-2].ival) * 60 + (int)(yyvsp[0].dval);
			global.time.tv_usec = (int)(1000000*(((yyvsp[0].dval) - (int)(yyvsp[0].dval)))+0.5);
		    }
#line 2643 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 36:
#line 1098 "gram.y" /* yacc.c:1648  */
    { 
			if ((yyvsp[-2].ival) > 59) {
			    pmsprintf(mess, sizeof(mess), "Minutes (%d) in time clause more than 59", (yyvsp[-2].ival));
			    yywarn(mess);
			}
			if ((yyvsp[0].ival) > 59) {
			    pmsprintf(mess, sizeof(mess), "Seconds (%d) in time clause more than 59", (yyvsp[0].ival));
			    yywarn(mess);
			}
			global.time.tv_sec = (yyvsp[-4].ival) * 3600 + (yyvsp[-2].ival) * 60 + (yyvsp[0].ival);
		    }
#line 2659 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 37:
#line 1110 "gram.y" /* yacc.c:1648  */
    { 
			if ((yyvsp[-2].ival) > 59) {
			    pmsprintf(mess, sizeof(mess), "Minutes (%d) in time clause more than 59", (yyvsp[-2].ival));
			    yywarn(mess);
			}
			if ((yyvsp[0].dval) > 59) {
			    pmsprintf(mess, sizeof(mess), "Seconds (%.6f) in time clause more than 59", (yyvsp[0].dval));
			    yywarn(mess);
			}
			global.time.tv_sec = (yyvsp[-2].ival) * 60 + (int)(yyvsp[0].dval);
			global.time.tv_usec = (int)(1000000*(((yyvsp[0].dval) - (int)(yyvsp[0].dval)))+0.5);
		    }
#line 2676 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 38:
#line 1123 "gram.y" /* yacc.c:1648  */
    { 
			if ((yyvsp[-2].ival) > 59) {
			    pmsprintf(mess, sizeof(mess), "Minutes (%d) in time clause more than 59", (yyvsp[-2].ival));
			    yywarn(mess);
			}
			if ((yyvsp[0].ival) > 59) {
			    pmsprintf(mess, sizeof(mess), "Seconds (%d) in time clause more than 59", (yyvsp[0].ival));
			    yywarn(mess);
			}
			global.time.tv_sec = (yyvsp[-2].ival) * 60 + (yyvsp[0].ival);
		    }
#line 2692 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 39:
#line 1135 "gram.y" /* yacc.c:1648  */
    {
			if ((yyvsp[0].dval) > 59) {
			    pmsprintf(mess, sizeof(mess), "Seconds (%.6f) in time clause more than 59", (yyvsp[0].dval));
			    yywarn(mess);
			}
			global.time.tv_sec = (int)(yyvsp[0].dval);
			global.time.tv_usec = (int)(1000000*(((yyvsp[0].dval) - (int)(yyvsp[0].dval)))+0.5);
		    }
#line 2705 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 40:
#line 1144 "gram.y" /* yacc.c:1648  */
    {
			if ((yyvsp[0].ival) > 59) {
			    pmsprintf(mess, sizeof(mess), "Seconds (%d) in time clause more than 59", (yyvsp[0].ival));
			    yywarn(mess);
			}
			global.time.tv_sec = (yyvsp[0].ival);
			global.time.tv_usec = 0;
		    }
#line 2718 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 41:
#line 1155 "gram.y" /* yacc.c:1648  */
    {
			if (current_star_indom) {
			    __pmContext		*ctxp;
			    __pmHashCtl		*hcp;
			    __pmHashNode	*node;

			    ctxp = __pmHandleToPtr(pmWhichContext());
			    assert(ctxp != NULL);
    /*
     * Note: This application is single threaded, and once we have ctxp
     *	     the associated __pmContext will not move and will only be
     *	     accessed or modified synchronously either here or in libpcp.
     *	     We unlock the context so that it can be locked as required
     *	     within libpcp.
     */
			    PM_UNLOCK(ctxp->c_lock);
			    hcp = &ctxp->c_archctl->ac_log->l_hashindom;
			    star_domain = pmInDom_domain((yyvsp[0].indom));
			    for (node = __pmHashWalk(hcp, PM_HASH_WALK_START);
				 node != NULL;
				 node = __pmHashWalk(hcp, PM_HASH_WALK_NEXT)) {
				if (pmInDom_domain((pmInDom)(node->key)) == star_domain)
				    current_indomspec = start_indom((pmInDom)(node->key));
			    }
			    do_walk_indom = 1;
			}
			else {
			    current_indomspec = start_indom((yyvsp[0].indom));
			    do_walk_indom = 0;
			}
		    }
#line 2754 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 43:
#line 1188 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting <domain>.<serial> or <domain>.* in indom rule");
			yyerror(mess);
		    }
#line 2763 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 44:
#line 1195 "gram.y" /* yacc.c:1648  */
    {
			int		domain;
			int		serial;
			int		sts;
			sts = sscanf((yyvsp[0].str), "%d.%d", &domain, &serial);
			if (sts < 2) {
			    pmsprintf(mess, sizeof(mess), "Missing serial field for indom");
			    yyerror(mess);
			}
			if (domain < 1 || domain >= DYNAMIC_PMID) {
			    pmsprintf(mess, sizeof(mess), "Illegal domain field (%d) for indom", domain);
			    yyerror(mess);
			}
			if (serial < 0 || serial >= 4194304) {
			    pmsprintf(mess, sizeof(mess), "Illegal serial field (%d) for indom", serial);
			    yyerror(mess);
			}
			current_star_indom = 0;
			free((yyvsp[0].str));
			(yyval.indom) = pmInDom_build(domain, serial);
		    }
#line 2789 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 45:
#line 1217 "gram.y" /* yacc.c:1648  */
    {
			int		domain;
			sscanf((yyvsp[0].str), "%d.", &domain);
			if (domain < 1 || domain >= DYNAMIC_PMID) {
			    pmsprintf(mess, sizeof(mess), "Illegal domain field (%d) for indom", domain);
			    yyerror(mess);
			}
			current_star_indom = 1;
			free((yyvsp[0].str));
			(yyval.indom) = pmInDom_build(domain, 0);
		    }
#line 2805 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 50:
#line 1239 "gram.y" /* yacc.c:1648  */
    {
			indomspec_t	*ip;
			for (ip = walk_indom(W_START); ip != NULL; ip = walk_indom(W_NEXT)) {
			    pmInDom	indom;
			    if (indom_root->new_indom != indom_root->old_indom) {
				pmsprintf(mess, sizeof(mess), "Duplicate indom clause for indom %s", pmInDomStr(indom_root->old_indom));
				yyerror(mess);
			    }
			    if (current_star_indom)
				indom = pmInDom_build(pmInDom_domain((yyvsp[0].indom)), pmInDom_serial(ip->old_indom));
			    else
				indom = (yyvsp[0].indom);
			    if (indom != ip->old_indom)
				ip->new_indom = indom;
			    else {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Instance domain %s: indom: No change", pmInDomStr(ip->old_indom));
				    yywarn(mess);
				}
			    }
			    ip->indom_flags |= (yyvsp[-1].ival);
			}
		    }
#line 2834 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 51:
#line 1264 "gram.y" /* yacc.c:1648  */
    {
			indomspec_t	*ip;
			for (ip = walk_indom(W_START); ip != NULL; ip = walk_indom(W_NEXT)) {
			    if (change_inst_by_name(ip->old_indom, (yyvsp[-2].str), (yyvsp[0].str)) < 0)
				yyerror(mess);
			}
			free((yyvsp[-2].str));
			/* Note: $4 referenced from new_iname[] */
		    }
#line 2848 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 52:
#line 1274 "gram.y" /* yacc.c:1648  */
    {
			indomspec_t	*ip;
			for (ip = walk_indom(W_START); ip != NULL; ip = walk_indom(W_NEXT)) {
			    if (change_inst_by_name(ip->old_indom, (yyvsp[-2].str), NULL) < 0)
			    	yyerror(mess);
			}
			free((yyvsp[-2].str));
		    }
#line 2861 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 53:
#line 1283 "gram.y" /* yacc.c:1648  */
    {
			indomspec_t	*ip;
			for (ip = walk_indom(W_START); ip != NULL; ip = walk_indom(W_NEXT)) {
			    if (change_inst_by_inst(ip->old_indom, (yyvsp[-2].ival), (yyvsp[0].ival)) < 0)
				yyerror(mess);
			}
		    }
#line 2873 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 54:
#line 1291 "gram.y" /* yacc.c:1648  */
    {
			indomspec_t	*ip;
			for (ip = walk_indom(W_START); ip != NULL; ip = walk_indom(W_NEXT)) {
			    if (change_inst_by_inst(ip->old_indom, (yyvsp[-2].ival), PM_IN_NULL) < 0)
				yyerror(mess);
			}
		    }
#line 2885 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 55:
#line 1299 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting <domain>.<serial> or <domain>.* in indom clause");
			yyerror(mess);
		    }
#line 2894 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 56:
#line 1304 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting -> in indom clause");
			yyerror(mess);
		    }
#line 2903 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 57:
#line 1309 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting new external instance name string or DELETE in iname clause");
			yyerror(mess);
		    }
#line 2912 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 58:
#line 1314 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting -> in iname clause");
			yyerror(mess);
		    }
#line 2921 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 59:
#line 1319 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting old external instance name string in iname clause");
			yyerror(mess);
		    }
#line 2930 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 60:
#line 1324 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting new internal instance identifier or DELETE in inst clause");
			yyerror(mess);
		    }
#line 2939 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 61:
#line 1329 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting -> in inst clause");
			yyerror(mess);
		    }
#line 2948 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 62:
#line 1334 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting old internal instance identifier in inst clause");
			yyerror(mess);
		    }
#line 2957 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 63:
#line 1340 "gram.y" /* yacc.c:1648  */
    { (yyval.ival) = INDOM_DUPLICATE; }
#line 2963 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 64:
#line 1341 "gram.y" /* yacc.c:1648  */
    { (yyval.ival) = 0; }
#line 2969 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 65:
#line 1345 "gram.y" /* yacc.c:1648  */
    {
			if (current_star_metric) {
			    __pmContext		*ctxp;
			    __pmHashCtl		*hcp;
			    __pmHashNode	*node;

			    ctxp = __pmHandleToPtr(pmWhichContext());
			    assert(ctxp != NULL);
    /*
     * Note: This application is single threaded, and once we have ctxp
     *	     the associated __pmContext will not move and will only be
     *	     accessed or modified synchronously either here or in libpcp.
     *	     We unlock the context so that it can be locked as required
     *	     within libpcp.
     */
			    PM_UNLOCK(ctxp->c_lock);
			    hcp = &ctxp->c_archctl->ac_log->l_hashpmid;
			    star_domain = pmID_domain((yyvsp[0].pmid));
			    if (current_star_metric == 1)
				star_cluster = pmID_cluster((yyvsp[0].pmid));
			    else
				star_cluster = PM_ID_NULL;
			    for (node = __pmHashWalk(hcp, PM_HASH_WALK_START);
				 node != NULL;
				 node = __pmHashWalk(hcp, PM_HASH_WALK_NEXT)) {
				if (pmID_domain((pmID)(node->key)) == star_domain &&
				    (star_cluster == PM_ID_NULL ||
				     star_cluster == pmID_cluster((pmID)(node->key))))
				    current_metricspec = start_metric((pmID)(node->key));
			    }
			    do_walk_metric = 1;
			}
			else {
			    if ((yyvsp[0].pmid) == PM_ID_NULL)
				/* metric not in archive */
				current_metricspec = NULL;
			    else
				current_metricspec = start_metric((yyvsp[0].pmid));
			    do_walk_metric = 0;
			}
		    }
#line 3015 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 67:
#line 1388 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting metric name or <domain>.<cluster>.<item> or <domain>.<cluster>.* or <domain>.*.* in metric rule");
			yyerror(mess);
		    }
#line 3024 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 69:
#line 1396 "gram.y" /* yacc.c:1648  */
    {
			int	sts;
			pmID	pmid;
			sts = pmLookupName(1, &(yyvsp[0].str), &pmid);
			if (sts < 0) {
			    if (wflag) {
				pmsprintf(mess, sizeof(mess), "Metric: %s: %s", (yyvsp[0].str), pmErrStr(sts));
				yywarn(mess);
			    }
			    pmid = PM_ID_NULL;
			}
			current_star_metric = 0;
			free((yyvsp[0].str));
			(yyval.pmid) = pmid;
		    }
#line 3044 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 70:
#line 1414 "gram.y" /* yacc.c:1648  */
    {
			int	domain;
			int	cluster;
			int	item;
			int	sts;
			sts = sscanf((yyvsp[0].str), "%d.%d.%d", &domain, &cluster, &item);
			assert(sts == 3);
			if (domain < 1 || domain > DYNAMIC_PMID) {
			    pmsprintf(mess, sizeof(mess), "Illegal domain field (%d) for pmid", domain);
			    yyerror(mess);
			}
			else if (domain == DYNAMIC_PMID) {
			    pmsprintf(mess, sizeof(mess), "Dynamic metric domain field (%d) for pmid", domain);
			    yywarn(mess);
			}
			if (cluster < 0 || cluster >= 4096) {
			    pmsprintf(mess, sizeof(mess), "Illegal cluster field (%d) for pmid", cluster);
			    yyerror(mess);
			}
			if (item < 0 || item >= 1024) {
			    pmsprintf(mess, sizeof(mess), "Illegal item field (%d) for pmid", item);
			    yyerror(mess);
			}
			current_star_metric = 0;
			free((yyvsp[0].str));
			(yyval.pmid) = pmID_build(domain, cluster, item);
		    }
#line 3076 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 71:
#line 1442 "gram.y" /* yacc.c:1648  */
    {
			int	domain;
			int	cluster;
			int	sts;
			sts = sscanf((yyvsp[0].str), "%d.%d.", &domain, &cluster);
			if (domain < 1 || domain > DYNAMIC_PMID) {
			    pmsprintf(mess, sizeof(mess), "Illegal domain field (%d) for pmid", domain);
			    yyerror(mess);
			}
			else if (domain == DYNAMIC_PMID) {
			    pmsprintf(mess, sizeof(mess), "Dynamic metric domain field (%d) for pmid", domain);
			    yywarn(mess);
			}
			if (sts == 2) {
			    if (cluster >= 4096) {
				pmsprintf(mess, sizeof(mess), "Illegal cluster field (%d) for pmid", cluster);
				yyerror(mess);
			    }
			    current_star_metric = 1;
			}
			else {
			    cluster = 0;
			    current_star_metric = 2;
			}
			free((yyvsp[0].str));
			(yyval.pmid) = pmID_build(domain, cluster, 0);
		    }
#line 3108 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 76:
#line 1480 "gram.y" /* yacc.c:1648  */
    {
			metricspec_t	*mp;
			pmID		pmid;
			for (mp = walk_metric(W_START, METRIC_CHANGE_PMID, "pmid", 0); mp != NULL; mp = walk_metric(W_NEXT, METRIC_CHANGE_PMID, "pmid", 0)) {
			    if (current_star_metric == 1)
				pmid = pmID_build(pmID_domain((yyvsp[0].pmid)), pmID_cluster((yyvsp[0].pmid)), pmID_item(mp->old_desc.pmid));
			    else if (current_star_metric == 2)
				pmid = pmID_build(pmID_domain((yyvsp[0].pmid)), pmID_cluster(mp->old_desc.pmid), pmID_item(mp->old_desc.pmid));
			    else
				pmid = (yyvsp[0].pmid);
			    if (pmid == mp->old_desc.pmid) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Metric: %s (%s): pmid: No change", mp->old_name, pmIDStr(mp->old_desc.pmid));
				    yywarn(mess);
				}
			    }
			    else {
				mp->new_desc.pmid = pmid;
				mp->flags |= METRIC_CHANGE_PMID;
			    }
			}
		    }
#line 3136 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 77:
#line 1504 "gram.y" /* yacc.c:1648  */
    {
			metricspec_t	*mp;
			for (mp = walk_metric(W_START, METRIC_CHANGE_NAME, "name", 0); mp != NULL; mp = walk_metric(W_NEXT, METRIC_CHANGE_NAME, "name", 0)) {
			    if (strcmp((yyvsp[0].str), mp->old_name) == 0) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Metric: %s (%s): name: No change", mp->old_name, pmIDStr(mp->old_desc.pmid));
				    yywarn(mess);
				}
			    }
			    else {
				int	sts;
				pmID	pmid;
				sts = pmLookupName(1, &(yyvsp[0].str), &pmid);
				if (sts >= 0) {
				    pmsprintf(mess, sizeof(mess), "Metric name %s already assigned for PMID %s", (yyvsp[0].str), pmIDStr(pmid));
				    yyerror(mess);
				}
				mp->new_name = (yyvsp[0].str);
				mp->flags |= METRIC_CHANGE_NAME;
			    }
			}
		    }
#line 3164 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 78:
#line 1528 "gram.y" /* yacc.c:1648  */
    {
			metricspec_t	*mp;
			for (mp = walk_metric(W_START, METRIC_CHANGE_TYPE, "type", 0); mp != NULL; mp = walk_metric(W_NEXT, METRIC_CHANGE_TYPE, "type", 0)) {
			    if ((yyvsp[0].ival) == mp->old_desc.type) {
				/* old == new, so no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Metric: %s (%s): type: PM_TYPE_%s: No change", mp->old_name, pmIDStr(mp->old_desc.pmid), pmTypeStr(mp->old_desc.type));
				    yywarn(mess);
				}
			    }
			    else {
				if (mp->old_desc.type == PM_TYPE_32 ||
				    mp->old_desc.type == PM_TYPE_U32 ||
				    mp->old_desc.type == PM_TYPE_64 ||
				    mp->old_desc.type == PM_TYPE_U64 ||
				    mp->old_desc.type == PM_TYPE_FLOAT ||
				    mp->old_desc.type == PM_TYPE_DOUBLE) {
				    mp->new_desc.type = (yyvsp[0].ival);
				    mp->flags |= METRIC_CHANGE_TYPE;
				}
				else {
				    pmsprintf(mess, sizeof(mess), "Old type (PM_TYPE_%s) must be numeric", pmTypeStr(mp->old_desc.type));
				    yyerror(mess);
				}
			    }
			}
		    }
#line 3196 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 79:
#line 1556 "gram.y" /* yacc.c:1648  */
    {
			metricspec_t	*mp;
			for (mp = walk_metric(W_START, METRIC_CHANGE_TYPE, "type", 1); mp != NULL; mp = walk_metric(W_NEXT, METRIC_CHANGE_TYPE, "type", 1)) {
			    if (mp->old_desc.type != (yyvsp[-2].ival)) {
				if (wflag) {
				    char	tbuf0[20];
				    char	tbuf1[20];
				    pmTypeStr_r(mp->old_desc.type, tbuf0, sizeof(tbuf0));
				    pmTypeStr_r((yyvsp[0].ival), tbuf1, sizeof(tbuf1));
				    pmsprintf(mess, sizeof(mess), "Metric: %s (%s): type: PM_TYPE_%s: No conditional change to PM_TYPE_%s", mp->old_name, pmIDStr(mp->old_desc.pmid), tbuf0, tbuf1);
				    yywarn(mess);
				}
			    }
			    else {
				if (mp->old_desc.type == PM_TYPE_32 ||
				    mp->old_desc.type == PM_TYPE_U32 ||
				    mp->old_desc.type == PM_TYPE_64 ||
				    mp->old_desc.type == PM_TYPE_U64 ||
				    mp->old_desc.type == PM_TYPE_FLOAT ||
				    mp->old_desc.type == PM_TYPE_DOUBLE) {
				    mp->new_desc.type = (yyvsp[0].ival);
				    mp->flags |= METRIC_CHANGE_TYPE;
				}
				else {
				    pmsprintf(mess, sizeof(mess), "Old type (PM_TYPE_%s) must be numeric", pmTypeStr(mp->old_desc.type));
				    yyerror(mess);
				}
			    }
			}
		    }
#line 3231 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 80:
#line 1587 "gram.y" /* yacc.c:1648  */
    {
			metricspec_t	*mp;
			pmInDom		indom;
			for (mp = walk_metric(W_START, METRIC_CHANGE_INDOM, "indom", 0); mp != NULL; mp = walk_metric(W_NEXT, METRIC_CHANGE_INDOM, "indom", 0)) {
			    if (current_star_indom)
				indom = pmInDom_build(pmInDom_domain((yyvsp[-1].indom)), pmInDom_serial(mp->old_desc.indom));
			    else
				indom = (yyvsp[-1].indom);
			    if (indom == mp->old_desc.indom) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Metric: %s (%s): indom: %s: No change", mp->old_name, pmIDStr(mp->old_desc.pmid), pmInDomStr(mp->old_desc.indom));
				    yywarn(mess);
				}
			    }
			    else {
				if ((output == OUTPUT_MIN ||
					  output == OUTPUT_MAX ||
					  output == OUTPUT_SUM ||
					  output == OUTPUT_AVG) &&
					 mp->old_desc.type != PM_TYPE_32 &&
					 mp->old_desc.type != PM_TYPE_U32 &&
					 mp->old_desc.type != PM_TYPE_64 &&
					 mp->old_desc.type != PM_TYPE_U64 &&
					 mp->old_desc.type != PM_TYPE_FLOAT &&
					 mp->old_desc.type != PM_TYPE_DOUBLE) {
				    pmsprintf(mess, sizeof(mess), "OUTPUT option MIN, MAX, AVG or SUM requires type to be numeric, not PM_TYPE_%s", pmTypeStr(mp->old_desc.type));
				    yyerror(mess);
				}
				mp->new_desc.indom = indom;
				mp->flags |= METRIC_CHANGE_INDOM;
				mp->output = output;
				if (output == OUTPUT_ONE) {
				    mp->one_name = one_name;
				    mp->one_inst = one_inst;
				    if (mp->old_desc.indom == PM_INDOM_NULL)
					/*
					 * singular input, pick first (only)
					 * value, not one_inst matching ...
					 * one_inst used for output instance
					 * id
					 */
					mp->output = OUTPUT_FIRST;
				}
				if (output == OUTPUT_ALL) {
				    /*
				     * No OUTPUT clause, set up the defaults
				     * based on indom types:
				     * non-NULL -> NULL
				     *		OUTPUT_FIRST, inst PM_IN_NULL
				     * NULL -> non-NULL
				     *		OUTPUT_FIRST, inst 0
				     * non-NULL -> non-NULL
				     * 		all instances selected
				     *		(nothing to do for defaults)
				     * NULL -> NULL
				     *		caught above in no change case
				     */
				    if (mp->old_desc.indom != PM_INDOM_NULL &&
				        mp->new_desc.indom == PM_INDOM_NULL) {
					mp->output = OUTPUT_FIRST;
					mp->one_inst = PM_IN_NULL;
				    }
				    else if (mp->old_desc.indom == PM_INDOM_NULL &&
				             mp->new_desc.indom != PM_INDOM_NULL) {
					mp->output = OUTPUT_FIRST;
					mp->one_inst = 0;
				    }
				}
			    }
			}
			output = OUTPUT_ALL;	/* for next time */
		    }
#line 3309 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 81:
#line 1661 "gram.y" /* yacc.c:1648  */
    {
			metricspec_t	*mp;
			for (mp = walk_metric(W_START, METRIC_CHANGE_SEM, "sem", 0); mp != NULL; mp = walk_metric(W_NEXT, METRIC_CHANGE_SEM, "sem", 0)) {
			    if ((yyvsp[0].ival) == mp->old_desc.sem) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Metric: %s (%s): sem: %s: No change", mp->old_name, pmIDStr(mp->old_desc.pmid), SemStr(mp->old_desc.sem));
				    yywarn(mess);
				}
			    }
			    else {
				mp->new_desc.sem = (yyvsp[0].ival);
				mp->flags |= METRIC_CHANGE_SEM;
			    }
			}
		    }
#line 3330 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 82:
#line 1678 "gram.y" /* yacc.c:1648  */
    {
			metricspec_t	*mp;
			for (mp = walk_metric(W_START, METRIC_CHANGE_UNITS, "units", 0); mp != NULL; mp = walk_metric(W_NEXT, METRIC_CHANGE_UNITS, "units", 0)) {
			    if ((yyvsp[-11].ival) == mp->old_desc.units.dimSpace &&
			        (yyvsp[-9].ival) == mp->old_desc.units.dimTime &&
			        (yyvsp[-7].ival) == mp->old_desc.units.dimCount &&
			        (yyvsp[-5].ival) == mp->old_desc.units.scaleSpace &&
			        (yyvsp[-3].ival) == mp->old_desc.units.scaleTime &&
			        (yyvsp[-1].ival) == mp->old_desc.units.scaleCount) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Metric: %s (%s): units: %s: No change", mp->old_name, pmIDStr(mp->old_desc.pmid), pmUnitsStr(&mp->old_desc.units));
				    yywarn(mess);
				}
			    }
			    else {
				mp->new_desc.units.dimSpace = (yyvsp[-11].ival);
				mp->new_desc.units.dimTime = (yyvsp[-9].ival);
				mp->new_desc.units.dimCount = (yyvsp[-7].ival);
				mp->new_desc.units.scaleSpace = (yyvsp[-5].ival);
				mp->new_desc.units.scaleTime = (yyvsp[-3].ival);
				mp->new_desc.units.scaleCount = (yyvsp[-1].ival);
				mp->flags |= METRIC_CHANGE_UNITS;
				if ((yyvsp[0].ival) == 1) {
				    if ((yyvsp[-11].ival) == mp->old_desc.units.dimSpace &&
					(yyvsp[-9].ival) == mp->old_desc.units.dimTime &&
					(yyvsp[-7].ival) == mp->old_desc.units.dimCount)
					/* OK, no dim changes */
					mp->flags |= METRIC_RESCALE;
				    else {
					if (wflag) {
					    pmsprintf(mess, sizeof(mess), "Metric: %s (%s): Dimension changed, cannot rescale", mp->old_name, pmIDStr(mp->old_desc.pmid));
					    yywarn(mess);
					}
				    }
				}
				else if (sflag) {
				    if ((yyvsp[-11].ival) == mp->old_desc.units.dimSpace &&
					(yyvsp[-9].ival) == mp->old_desc.units.dimTime &&
					(yyvsp[-7].ival) == mp->old_desc.units.dimCount)
					mp->flags |= METRIC_RESCALE;
				}
			    }
			}
		    }
#line 3380 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 83:
#line 1724 "gram.y" /* yacc.c:1648  */
    {
			metricspec_t	*mp;
			for (mp = walk_metric(W_START, METRIC_DELETE, "delete", 0); mp != NULL; mp = walk_metric(W_NEXT, METRIC_DELETE, "delete", 0)) {
			    mp->flags |= METRIC_DELETE;
			}
		    }
#line 3391 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 84:
#line 1731 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting <domain>.<cluster>.<item> or <domain>.<cluster>.* or <domain>.*.* in pmid clause");
			yyerror(mess);
		    }
#line 3400 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 85:
#line 1736 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting metric name in iname clause");
			yyerror(mess);
		    }
#line 3409 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 86:
#line 1741 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting XXX (from PM_TYPE_XXX) in type clause");
			yyerror(mess);
		    }
#line 3418 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 87:
#line 1746 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting XXX (from PM_TYPE_XXX) after if in type clause");
			yyerror(mess);
		    }
#line 3427 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 88:
#line 1751 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting XXX (from PM_TYPE_XXX) in type clause");
			yyerror(mess);
		    }
#line 3436 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 89:
#line 1756 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting <domain>.<serial> or NULL in indom clause");
			yyerror(mess);
		    }
#line 3445 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 90:
#line 1761 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting XXX (from PM_SEM_XXX) in sem clause");
			yyerror(mess);
		    }
#line 3454 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 91:
#line 1766 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting 3 numeric values for dim* fields of units");
			yyerror(mess);
		    }
#line 3463 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 92:
#line 1771 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting 0 or XXX (from PM_SPACE_XXX) for scaleSpace field of units");
			yyerror(mess);
		    }
#line 3472 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 93:
#line 1776 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting 0 or XXX (from PM_TIME_XXX) for scaleTime field of units");
			yyerror(mess);
		    }
#line 3481 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 94:
#line 1781 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting 0 or ONE for scaleCount field of units");
			yyerror(mess);
		    }
#line 3490 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 96:
#line 1789 "gram.y" /* yacc.c:1648  */
    {
			(yyval.indom) = PM_INDOM_NULL;
		    }
#line 3498 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 97:
#line 1795 "gram.y" /* yacc.c:1648  */
    {
			output = OUTPUT_ONE;
			one_inst = (yyvsp[0].ival);
			one_name = NULL;
		    }
#line 3508 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 98:
#line 1801 "gram.y" /* yacc.c:1648  */
    {
			output = OUTPUT_ONE;
			one_inst = PM_IN_NULL;
			one_name = (yyvsp[0].str);
		    }
#line 3518 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 99:
#line 1807 "gram.y" /* yacc.c:1648  */
    {
			output = (yyvsp[0].ival);
		    }
#line 3526 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 100:
#line 1811 "gram.y" /* yacc.c:1648  */
    {
			pmsprintf(mess, sizeof(mess), "Expecting FIRST or LAST or INST or INAME or MIN or MAX or AVG for OUTPUT instance option");
			yyerror(mess);
		    }
#line 3535 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 102:
#line 1818 "gram.y" /* yacc.c:1648  */
    { (yyval.ival) = 1; }
#line 3541 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 103:
#line 1820 "gram.y" /* yacc.c:1648  */
    { (yyval.ival) = 0; }
#line 3547 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 107:
#line 1831 "gram.y" /* yacc.c:1648  */
    {
			__pmContext	*ctxp;
			__pmHashCtl	*hcp1;
			__pmHashNode	*node1;
			int		target_types;
			int		this_type;
			int		type;

			ctxp = __pmHandleToPtr(pmWhichContext());
			assert(ctxp != NULL);
    /*
     * Note: This application is single threaded, and once we have ctxp,
     *	     the associated __pmContext will not move and will only be
     *	     accessed or modified synchronously either here or in libpcp.
     *	     We unlock the context so that it can be locked as required
     *	     within libpcp.
     */
			PM_UNLOCK(ctxp->c_lock);
			
			current_textspec = NULL;
			if ((yyvsp[-1].pmid) == PM_ID_NULL) {
			    /* Metric referenced by name is not in the archive */
			    do_walk_text = 0;
			}
			else {
			    int found = 0;
			    
			    if (current_star_metric) {
				/* Set up for metrics specified using globbing. */
				star_domain = pmID_domain((yyvsp[-1].pmid));
				if (current_star_metric == 1)
				    star_cluster = pmID_cluster((yyvsp[-1].pmid));
				else
				    star_cluster = PM_ID_NULL;
			    }

			    /* We're looking for text of the specified type(s) for metric(s). */
			    target_types = PM_TEXT_PMID | (yyvsp[0].ival);
			    hcp1 = &ctxp->c_archctl->ac_log->l_hashtext;
			    for (node1 = __pmHashWalk(hcp1, PM_HASH_WALK_START);
				 node1 != NULL;
				 node1 = __pmHashWalk(hcp1, PM_HASH_WALK_NEXT)) {
				__pmHashCtl	*hcp2;
				__pmHashNode	*node2;

				/* Was this object type selected? */
				this_type = (int)(node1->key);
				if ((this_type & target_types) != this_type)
				    continue;

				/*
				 * Collect the text records associated with the specified
				 * metric(s).
				 */
				hcp2 = (__pmHashCtl *)(node1->data);
				for (node2 = __pmHashWalk(hcp2, PM_HASH_WALK_START);
				     node2 != NULL;
				     node2 = __pmHashWalk(hcp2, PM_HASH_WALK_NEXT)) {
				    if (current_star_metric) {
					/* Match the globbed metric spec and keep looking. */
					if (pmID_domain((pmID)(node2->key)) == star_domain &&
					    (star_cluster == PM_ID_NULL ||
					     star_cluster == pmID_cluster((pmID)(node2->key)))) {
					    current_textspec = start_text(this_type, (pmID)(node2->key));
					    if (current_textspec) {
						current_textspec->flags |= TEXT_ACTIVE;
						++found;
					    }

					}
				    }
				    else {
					/* Match the exact metric PMID. */
					if ((pmID)(node2->key) == (yyvsp[-1].pmid)) {
					    current_textspec = start_text(this_type, (pmID)(node2->key));
					    if (current_textspec) {
						current_textspec->flags |= TEXT_ACTIVE;
						++found;
					    }
					    /*
					     * Stop looking if we have found all of the specified
					     * types.
					     */
					    type = this_type & PM_TEXT_TYPE_MASK;
					    target_types ^= type;
					    if ((target_types & PM_TEXT_TYPE_MASK) == 0)
						break;
					}
				    }
				}
				if ((target_types & PM_TEXT_TYPE_MASK) == 0)
				    break;
			    }
			    do_walk_text = (found > 1);
			}
		    }
#line 3648 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 109:
#line 1931 "gram.y" /* yacc.c:1648  */
    { (yyval.ival) = (yyvsp[0].ival); }
#line 3654 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 110:
#line 1933 "gram.y" /* yacc.c:1648  */
    { (yyval.ival) = PM_TEXT_ONELINE; }
#line 3660 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 111:
#line 1937 "gram.y" /* yacc.c:1648  */
    { (yyval.ival) = (yyvsp[0].ival); }
#line 3666 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 112:
#line 1939 "gram.y" /* yacc.c:1648  */
    { (yyval.ival) = (yyvsp[-1].ival) | (yyvsp[0].ival); }
#line 3672 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 113:
#line 1943 "gram.y" /* yacc.c:1648  */
    { (yyval.ival) = PM_TEXT_ONELINE | PM_TEXT_HELP; }
#line 3678 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 114:
#line 1945 "gram.y" /* yacc.c:1648  */
    { (yyval.ival) = PM_TEXT_HELP; }
#line 3684 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 115:
#line 1947 "gram.y" /* yacc.c:1648  */
    { (yyval.ival) = PM_TEXT_ONELINE; }
#line 3690 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 117:
#line 1952 "gram.y" /* yacc.c:1648  */
    {
			textspec_t	*tp;
			for (tp = walk_text(W_START, TEXT_ACTIVE, "active", 0); tp != NULL; tp = walk_text(W_NEXT, 0, "", 0)) {
			    tp->flags &= ~TEXT_ACTIVE;
			}
		    }
#line 3701 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 120:
#line 1965 "gram.y" /* yacc.c:1648  */
    {
			textspec_t	*tp;
			for (tp = walk_text(W_START, TEXT_DELETE, "delete", 0); tp != NULL; tp = walk_text(W_NEXT, TEXT_DELETE, "delete", 0)) {
			    tp->flags |= TEXT_DELETE;
			}
		    }
#line 3712 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 121:
#line 1972 "gram.y" /* yacc.c:1648  */
    {
			textspec_t	*tp;
			for (tp = walk_text(W_START, TEXT_CHANGE_TEXT, "text", 0); tp != NULL; tp = walk_text(W_NEXT, TEXT_CHANGE_TEXT, "text", 0)) {
			    if (tp->new_text) {
				if (strcmp(tp->new_text, (yyvsp[0].str)) == 0) {
				    pmsprintf(mess, sizeof(mess), "Duplicate text change clause");
				    yyerror(mess);
				}
				else {
				    pmsprintf(mess, sizeof(mess), "Conflicting text change clause");
				    yyerror(mess);
				}
				free((yyvsp[0].str));
			    }
			    else if (strcmp(tp->old_text, (yyvsp[0].str)) == 0) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Help text: No change");
				    yywarn(mess);
				}
				free((yyvsp[0].str));
			    }
			    else {
				tp->new_text = (yyvsp[0].str);
				tp->flags |= TEXT_CHANGE_TEXT;
			    }
			}
		    }
#line 3745 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 122:
#line 2001 "gram.y" /* yacc.c:1648  */
    {
			textspec_t	*tp;
			pmID		pmid;
			for (tp = walk_text(W_START, TEXT_CHANGE_ID, "id", 0); tp != NULL; tp = walk_text(W_NEXT, TEXT_CHANGE_ID, "id", 0)) {
			    if (current_star_metric == 1)
				pmid = pmID_build(pmID_domain((yyvsp[0].pmid)), pmID_cluster((yyvsp[0].pmid)), pmID_item(tp->old_id));
			    else if (current_star_metric == 2)
				pmid = pmID_build(pmID_domain((yyvsp[0].pmid)), pmID_cluster(tp->old_id), pmID_item(tp->old_id));
			    else
				pmid = (yyvsp[0].pmid);
			    if (pmid == tp->old_id) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Text for metric: %s: metric: No change", pmIDStr(tp->old_id));
				    yywarn(mess);
				}
			    }
			    else {
				const textspec_t *tp1;
				/* Warn if the target metric already has text of this type. */
				/*
				 * Search all of the change specs for others targeting
				 * the same metric.
				 */
				for (tp1 = text_root; tp1 != NULL; tp1 = tp1->t_next) {
				    if (! (tp1->flags & TEXT_CHANGE_ID))
					continue; /* not an id change spec */
				    if (tp1->new_type != tp->new_type)
					continue; /* target is a different type */
				    if (tp1 == tp)
					continue; /* same spec */
				    if (tp1->new_id == pmid) {
					/* conflict with another change spec. */
					pmsprintf(mess, sizeof(mess), "Text for metric: %s: metric: Conflicting metric change", pmIDStr(tp->old_id));
					yyerror(mess);
					break;
				    }
				}
				if (tp1 == NULL) {
				    /* No conflict */
				    tp->new_id = pmid;
				    tp->flags |= TEXT_CHANGE_ID;
				}
			    }
			}
		    }
#line 3796 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 123:
#line 2050 "gram.y" /* yacc.c:1648  */
    { (yyval.str) = (yyvsp[0].str); }
#line 3802 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 124:
#line 2052 "gram.y" /* yacc.c:1648  */
    { (yyval.str) = (yyvsp[0].str); }
#line 3808 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 125:
#line 2056 "gram.y" /* yacc.c:1648  */
    {
			__pmContext	*ctxp;
			__pmHashCtl	*hcp1;
			__pmHashNode	*node1;
			int		target_types;
			int		this_type;
			int		type;

			ctxp = __pmHandleToPtr(pmWhichContext());
			assert(ctxp != NULL);
    /*
     * Note: This application is single threaded, and once we have ctxp,
     *	     the associated __pmContext will not move and will only be
     *	     accessed or modified synchronously either here or in libpcp.
     *	     We unlock the context so that it can be locked as required
     *	     within libpcp.
     */
			PM_UNLOCK(ctxp->c_lock);
			
			current_textspec = NULL;
			if ((yyvsp[-1].indom) == PM_ID_NULL) {
			    /* Indom is not in the archive */
			    do_walk_text = 0;
			}
			else {
			    int found = 0;
			    
			    if (current_star_indom) {
				/* Set up for indoms specified using globbing. */
				star_domain = pmInDom_domain((yyvsp[-1].indom));
			    }

			    /* We're looking for text of the specified type(s) for indom(s). */
			    target_types = PM_TEXT_INDOM | (yyvsp[0].ival);
			    hcp1 = &ctxp->c_archctl->ac_log->l_hashtext;
			    for (node1 = __pmHashWalk(hcp1, PM_HASH_WALK_START);
				 node1 != NULL;
				 node1 = __pmHashWalk(hcp1, PM_HASH_WALK_NEXT)) {
				__pmHashCtl	*hcp2;
				__pmHashNode	*node2;

				/* Was this object type selected? */
				this_type = (int)(node1->key);
				if ((this_type & target_types) != this_type)
				    continue;

				/*
				 * Collect the text records associated with the specified
				 * metric(s).
				 */
				hcp2 = (__pmHashCtl *)(node1->data);
				for (node2 = __pmHashWalk(hcp2, PM_HASH_WALK_START);
				     node2 != NULL;
				     node2 = __pmHashWalk(hcp2, PM_HASH_WALK_NEXT)) {
				    if (current_star_indom) {
					/* Match the globbed metric spec and keep looking. */
					if (pmInDom_domain((pmID)(node2->key)) == star_domain) {
					    current_textspec = start_text(this_type, (pmID)(node2->key));
					    if (current_textspec) {
						current_textspec->flags |= TEXT_ACTIVE;
						++found;
					    }
					}
				    }
				    else {
					/* Match the exact indom id. */
					if ((pmID)(node2->key) == (yyvsp[-1].indom)) {
					    current_textspec = start_text(this_type, (pmID)(node2->key));
					    if (current_textspec) {
						current_textspec->flags |= TEXT_ACTIVE;
						++found;
					    }
					    /*
					     * Stop looking if we have found all of the specified
					     * types.
					     */
					    type = this_type & PM_TEXT_TYPE_MASK;
					    target_types ^= type;
					    if ((target_types & PM_TEXT_TYPE_MASK) == 0)
						break;
					}
				    }
				}
				if ((target_types & PM_TEXT_TYPE_MASK) == 0)
				    break;
			    }
			    do_walk_text = (found > 1);
			}
		    }
#line 3902 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 128:
#line 2150 "gram.y" /* yacc.c:1648  */
    {
			textspec_t	*tp;
			for (tp = walk_text(W_START, TEXT_ACTIVE, "active", 0); tp != NULL; tp = walk_text(W_NEXT, 0, "", 0)) {
			    tp->flags &= ~TEXT_ACTIVE;
			}
		    }
#line 3913 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 131:
#line 2163 "gram.y" /* yacc.c:1648  */
    {
			textspec_t	*tp;
			for (tp = walk_text(W_START, TEXT_DELETE, "delete", 0); tp != NULL; tp = walk_text(W_NEXT, TEXT_DELETE, "delete", 0)) {
			    tp->flags |= TEXT_DELETE;
			}
		    }
#line 3924 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 132:
#line 2170 "gram.y" /* yacc.c:1648  */
    {
			textspec_t	*tp;
			for (tp = walk_text(W_START, TEXT_CHANGE_TEXT, "text", 0); tp != NULL; tp = walk_text(W_NEXT, TEXT_CHANGE_TEXT, "text", 0)) {
			    if (tp->new_text) {
				if (strcmp(tp->new_text, (yyvsp[0].str)) == 0) {
				    pmsprintf(mess, sizeof(mess), "Duplicate text change clause");
				    yyerror(mess);
				}
				else {
				    pmsprintf(mess, sizeof(mess), "Conflicting text change clause");
				    yyerror(mess);
				}
				free((yyvsp[0].str));
			    }
			    else if (strcmp(tp->old_text, (yyvsp[0].str)) == 0) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Help text: No change");
				    yywarn(mess);
				}
				free((yyvsp[0].str));
			    }
			    else {
				tp->new_text = (yyvsp[0].str);
				tp->flags |= TEXT_CHANGE_TEXT;
			    }
			}
		    }
#line 3957 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 133:
#line 2199 "gram.y" /* yacc.c:1648  */
    {
			textspec_t	*tp;
			for (tp = walk_text(W_START, TEXT_CHANGE_ID, "id", 0); tp != NULL; tp = walk_text(W_NEXT, TEXT_CHANGE_ID, "id", 0)) {
			    pmInDom	indom;
			    if (tp->new_id != tp->old_id) {
				pmsprintf(mess, sizeof(mess), "Duplicate text clause for indom %s", pmInDomStr(tp->old_id));
				yyerror(mess);
			    }
			    if (current_star_indom)
				indom = pmInDom_build(pmInDom_domain((yyvsp[0].indom)), pmInDom_serial(tp->old_id));
			    else
				indom = (yyvsp[0].indom);
			    if (indom != tp->old_id) {
				tp->new_id = indom;
				tp->flags |= TEXT_CHANGE_ID;
			    }
			    else {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Text for instance domain %s: indom: No change", pmInDomStr(tp->old_id));
				    yywarn(mess);
				}
			    }
			}
		    }
#line 3987 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 141:
#line 2238 "gram.y" /* yacc.c:1648  */
    {
			__pmContext	*ctxp;
			__pmHashCtl	*hcp1;
			__pmHashNode	*node1;
			int		found = 0;

			ctxp = __pmHandleToPtr(pmWhichContext());
			assert(ctxp != NULL);
    /*
     * Note: This application is single threaded, and once we have ctxp,
     *	     the associated __pmContext will not move and will only be
     *	     accessed or modified synchronously either here or in libpcp.
     *	     We unlock the context so that it can be locked as required
     *	     within libpcp.
     */
			PM_UNLOCK(ctxp->c_lock);
			
			/* We're looking for context labels. */
			current_labelspec = NULL;
			hcp1 = &ctxp->c_archctl->ac_log->l_hashlabels;
			for (node1 = __pmHashWalk(hcp1, PM_HASH_WALK_START);
			     node1 != NULL;
			     node1 = __pmHashWalk(hcp1, PM_HASH_WALK_NEXT)) {
			    __pmHashCtl	*hcp2;
			    __pmHashNode	*node2;
			    int		this_type;

			    /* Was this object type selected? */
			    this_type = (int)(node1->key);
			    if (this_type != PM_LABEL_CONTEXT)
				continue;

			    /*
			     * Collect the label records associated with the specified
			     * metric(s).
			     */
			    hcp2 = (__pmHashCtl *)(node1->data);
			    for (node2 = __pmHashWalk(hcp2, PM_HASH_WALK_START);
				 node2 != NULL;
				 node2 = __pmHashWalk(hcp2, PM_HASH_WALK_NEXT)) {
				/* We want all of the context labels. */
				current_labelspec = start_label(this_type, (pmID)(node2->key), 0,
								current_label_name, current_label_value);
				if (current_labelspec) {
				    current_labelspec->flags |= LABEL_ACTIVE;
				    ++found;
				}
			    }
			}
			do_walk_label = found;
		    }
#line 4043 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 143:
#line 2293 "gram.y" /* yacc.c:1648  */
    { current_label_name = (yyvsp[-1].str); }
#line 4049 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 144:
#line 2295 "gram.y" /* yacc.c:1648  */
    { current_label_name = NULL; }
#line 4055 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 145:
#line 2297 "gram.y" /* yacc.c:1648  */
    {
			current_label_name = NULL;
			current_label_value = NULL;
		    }
#line 4064 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 146:
#line 2304 "gram.y" /* yacc.c:1648  */
    { (yyval.str) = (yyvsp[0].str); }
#line 4070 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 147:
#line 2306 "gram.y" /* yacc.c:1648  */
    {
			(yyval.str) = add_quotes((yyvsp[0].str));
			free((yyvsp[0].str));
		    }
#line 4079 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 148:
#line 2313 "gram.y" /* yacc.c:1648  */
    { current_label_value = (yyvsp[0].str); }
#line 4085 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 149:
#line 2315 "gram.y" /* yacc.c:1648  */
    { current_label_value = NULL; }
#line 4091 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 150:
#line 2317 "gram.y" /* yacc.c:1648  */
    { current_label_value = NULL; }
#line 4097 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 151:
#line 2321 "gram.y" /* yacc.c:1648  */
    { (yyval.str) = (yyvsp[0].str); }
#line 4103 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 152:
#line 2323 "gram.y" /* yacc.c:1648  */
    { (yyval.str) = (yyvsp[0].str); }
#line 4109 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 153:
#line 2325 "gram.y" /* yacc.c:1648  */
    { (yyval.str) = (yyvsp[0].str); }
#line 4115 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 154:
#line 2327 "gram.y" /* yacc.c:1648  */
    { (yyval.str) = (yyvsp[0].str); }
#line 4121 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 155:
#line 2329 "gram.y" /* yacc.c:1648  */
    { (yyval.str) = (yyvsp[0].str); }
#line 4127 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 156:
#line 2333 "gram.y" /* yacc.c:1648  */
    {
			(yyval.str) = dupcat("-", (yyvsp[0].str));
			free((yyvsp[0].str));
		    }
#line 4136 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 157:
#line 2338 "gram.y" /* yacc.c:1648  */
    { (yyval.str) = (yyvsp[0].str); }
#line 4142 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 158:
#line 2340 "gram.y" /* yacc.c:1648  */
    {
			(yyval.str) = dupcat("-", (yyvsp[0].str));
			free((yyvsp[0].str));
		    }
#line 4151 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 159:
#line 2345 "gram.y" /* yacc.c:1648  */
    { (yyval.str) = (yyvsp[0].str); }
#line 4157 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 161:
#line 2350 "gram.y" /* yacc.c:1648  */
    {
			deactivate_labels();
		    }
#line 4165 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 164:
#line 2360 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_DELETE, "delete", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_DELETE, "delete", 0)) {
			    lp->flags |= LABEL_DELETE;
			}
		    }
#line 4176 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 165:
#line 2367 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_CHANGE_LABEL, "label", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_LABEL, "label", 0)) {
			    if (lp->new_label != NULL) {
				pmsprintf(mess, sizeof(mess), "Duplicate label clause for context");
				yyerror(mess);
			    }
			    if (lp->old_label != NULL &&
				strcmp(lp->old_label, (yyvsp[0].str)) == 0) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for context: label: No change");
				    yywarn(mess);
				}
				free((yyvsp[0].str));
			    }
			    else {
				lp->new_label = (yyvsp[0].str);
				lp->flags |= LABEL_CHANGE_LABEL;
			    }
			}
		    }
#line 4203 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 166:
#line 2391 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_CHANGE_VALUE, "value", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_VALUE, "value", 0)) {
			    if (lp->new_value != NULL) {
				pmsprintf(mess, sizeof(mess), "Duplicate value clause for cluster %d.%d", pmID_domain(lp->old_id), pmID_cluster(lp->old_id));
				yyerror(mess);
			    }
			    if (lp->old_value != NULL &&
				strcmp(lp->old_value, (yyvsp[0].str)) == 0) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for cluster %d.%d: value: No change", pmID_domain(lp->old_id), pmID_cluster(lp->old_id));
				    yywarn(mess);
				}
				free((yyvsp[0].str));
			    }
			    else {
				lp->new_value = (yyvsp[0].str);
				lp->flags |= LABEL_CHANGE_VALUE;
			    }
			}
		    }
#line 4230 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 167:
#line 2415 "gram.y" /* yacc.c:1648  */
    {
			new_context_label();
		    }
#line 4238 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 168:
#line 2420 "gram.y" /* yacc.c:1648  */
    {
			/* The current label name and value must both NOT be specified. */
			if (current_label_name || current_label_value) {
			    pmsprintf(mess, sizeof(mess), "The target label name and value must both not be specified for a NEW label and will be ignored");
			    yywarn(mess);
			    if (current_label_name)
				free(current_label_name);
			    if (current_label_value)
				free(current_label_value);
			}
			current_label_name = (yyvsp[-1].str);
			current_label_value = (yyvsp[0].str);
		    }
#line 4256 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 169:
#line 2435 "gram.y" /* yacc.c:1648  */
    {
			__pmContext	*ctxp;
			__pmHashCtl	*hcp1;
			__pmHashNode	*node1;
			int		 found = 0;

			ctxp = __pmHandleToPtr(pmWhichContext());
			assert(ctxp != NULL);
    /*
     * Note: This application is single threaded, and once we have ctxp,
     *	     the associated __pmContext will not move and will only be
     *	     accessed or modified synchronously either here or in libpcp.
     *	     We unlock the context so that it can be locked as required
     *	     within libpcp.
     */
			PM_UNLOCK(ctxp->c_lock);
			
			current_labelspec = NULL;
			assert ((yyvsp[-1].ival) != PM_ID_NULL);
			current_label_id = (yyvsp[-1].ival);
			    
			/* We're looking for domain labels. */
			hcp1 = &ctxp->c_archctl->ac_log->l_hashlabels;
			for (node1 = __pmHashWalk(hcp1, PM_HASH_WALK_START);
			     node1 != NULL;
			     node1 = __pmHashWalk(hcp1, PM_HASH_WALK_NEXT)) {
			    __pmHashCtl	*hcp2;
			    __pmHashNode	*node2;
			    int		this_type;

			    /* Was this object type selected? */
			    this_type = (int)(node1->key);
			    if (this_type != PM_LABEL_DOMAIN)
				continue;

			    /*
			     * Collect the label records associated with the specified
			     * metric domain.
			     */
			    hcp2 = (__pmHashCtl *)(node1->data);
			    for (node2 = __pmHashWalk(hcp2, PM_HASH_WALK_START);
				 node2 != NULL;
				 node2 = __pmHashWalk(hcp2, PM_HASH_WALK_NEXT)) {
				/* Match the exact metric domain. */
				if ((pmID)(node2->key) == (yyvsp[-1].ival)) {
				    current_labelspec = start_label(this_type, (pmID)(node2->key), 0,
								    current_label_name, current_label_value);
				    if (current_labelspec) {
					current_labelspec->flags |= LABEL_ACTIVE;
					++found;
				    }
				}
			    }
			}
			do_walk_label = found;
		    }
#line 4317 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 171:
#line 2495 "gram.y" /* yacc.c:1648  */
    {
			int	domain;
			int	sts;
			sts = sscanf((yyvsp[0].str), "%d", &domain);
			assert(sts == 1);
			if (domain < 1 || domain > DYNAMIC_PMID) {
			    pmsprintf(mess, sizeof(mess), "Illegal domain field (%d) for pmid", domain);
			    yyerror(mess);
			}
			else if (domain == DYNAMIC_PMID) {
			    pmsprintf(mess, sizeof(mess), "Dynamic metric domain field (%d) for pmid", domain);
			    yywarn(mess);
			}
			current_star_metric = 0;
			free((yyvsp[0].str));
			(yyval.ival) = domain;
		    }
#line 4339 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 173:
#line 2516 "gram.y" /* yacc.c:1648  */
    {
			deactivate_labels();
		    }
#line 4347 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 176:
#line 2526 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_DELETE, "delete", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_DELETE, "delete", 0)) {
			    lp->flags |= LABEL_DELETE;
			}
		    }
#line 4358 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 177:
#line 2533 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			int		domain;
			int		sts;
			sts = sscanf((yyvsp[0].str), "%d", &domain);
			assert(sts == 1);
			free((yyvsp[0].str));
			for (lp = walk_label(W_START, LABEL_CHANGE_ID, "id", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_ID, "id", 0)) {
			    if (domain == lp->old_id) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for metric domain: %d: No change", lp->old_id);
				    yywarn(mess);
				}
			    }
			    else {
				/*
				 * No need to check for conflicts. Multiple label set records for
				 * the same domain are ok.
				 */
				lp->new_id = domain;
				lp->flags |= LABEL_CHANGE_ID;
			    }
			}
		    }
#line 4388 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 178:
#line 2559 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_CHANGE_LABEL, "label", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_LABEL, "label", 0)) {
			    if (lp->new_label != NULL) {
				pmsprintf(mess, sizeof(mess), "Duplicate label clause for domain %d", lp->old_id);
				yyerror(mess);
			    }
			    if (lp->old_label != NULL &&
				strcmp(lp->old_label, (yyvsp[0].str)) == 0) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for domain %d: label: No change", lp->old_id);
				    yywarn(mess);
				}
				free((yyvsp[0].str));
			    }
			    else {
				lp->new_label = (yyvsp[0].str);
				lp->flags |= LABEL_CHANGE_LABEL;
			    }
			}
		    }
#line 4415 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 179:
#line 2583 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_CHANGE_VALUE, "value", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_VALUE, "value", 0)) {
			    if (lp->new_value != NULL) {
				pmsprintf(mess, sizeof(mess), "Duplicate value clause for cluster %d.%d", pmID_domain(lp->old_id), pmID_cluster(lp->old_id));
				yyerror(mess);
			    }
			    if (lp->old_value != NULL &&
				strcmp(lp->old_value, (yyvsp[0].str)) == 0) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for cluster %d.%d: value: No change", pmID_domain(lp->old_id), pmID_cluster(lp->old_id));
				    yywarn(mess);
				}
				free((yyvsp[0].str));
			    }
			    else {
				lp->new_value = (yyvsp[0].str);
				lp->flags |= LABEL_CHANGE_VALUE;
			    }
			}
		    }
#line 4442 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 180:
#line 2607 "gram.y" /* yacc.c:1648  */
    {
			new_domain_label(current_label_id);
		    }
#line 4450 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 181:
#line 2613 "gram.y" /* yacc.c:1648  */
    {
			__pmContext	*ctxp;
			__pmHashCtl	*hcp1;
			__pmHashNode	*node1;
			int		found = 0;

			ctxp = __pmHandleToPtr(pmWhichContext());
			assert(ctxp != NULL);
    /*
     * Note: This application is single threaded, and once we have ctxp,
     *	     the associated __pmContext will not move and will only be
     *	     accessed or modified synchronously either here or in libpcp.
     *	     We unlock the context so that it can be locked as required
     *	     within libpcp.
     */
			PM_UNLOCK(ctxp->c_lock);
			
			current_labelspec = NULL;
			assert ((yyvsp[-1].ival) != PM_ID_NULL);
			current_label_id = (yyvsp[-1].ival);
			    
			if (current_star_metric) {
			    /* Set up for metrics specified using globbing. */
			    star_domain = pmID_domain((yyvsp[-1].ival));
			    star_cluster = PM_ID_NULL;
			}

			/* We're looking for cluster labels. */
			hcp1 = &ctxp->c_archctl->ac_log->l_hashlabels;
			for (node1 = __pmHashWalk(hcp1, PM_HASH_WALK_START);
			     node1 != NULL;
			     node1 = __pmHashWalk(hcp1, PM_HASH_WALK_NEXT)) {
			    __pmHashCtl		*hcp2;
			    __pmHashNode	*node2;
			    int			this_type;

			    /* Was this object type selected? */
			    this_type = (int)(node1->key);
			    if (this_type != PM_LABEL_CLUSTER)
				continue;

			    /*
			     * Collect the label records associated with the specified
			     * metric(s).
			     */
			    hcp2 = (__pmHashCtl *)(node1->data);
			    for (node2 = __pmHashWalk(hcp2, PM_HASH_WALK_START);
				 node2 != NULL;
				 node2 = __pmHashWalk(hcp2, PM_HASH_WALK_NEXT)) {
				if (current_star_metric) {
				    /* Match the globbed cluster spec and keep looking. */
				    if (pmID_domain((pmID)(node2->key)) == star_domain) {
					current_labelspec = start_label(this_type, (pmID)(node2->key), 0,
									current_label_name, current_label_value);
					if (current_labelspec) {
					    current_labelspec->flags |= LABEL_ACTIVE;
					    ++found;
					}
				    }
				}
				else {
				    /* Match the exact cluster spec. */
				    if ((pmID)(node2->key) == (yyvsp[-1].ival)) {
					current_labelspec = start_label(this_type, (pmID)(node2->key), 0,
									current_label_name, current_label_value);
					if (current_labelspec) {
					    current_labelspec->flags |= LABEL_ACTIVE;
					    ++found;
					}
				    }
				}
			    }
			}
			do_walk_label = found;
		    }
#line 4530 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 183:
#line 2692 "gram.y" /* yacc.c:1648  */
    {
			int	domain;
			int	cluster;
			int	sts;
			sts = sscanf((yyvsp[0].str), "%d.%d", &domain, &cluster);
			assert(sts == 2);
			if (domain < 1 || domain > DYNAMIC_PMID) {
			    pmsprintf(mess, sizeof(mess), "Illegal domain field (%d) for pmid", domain);
			    yyerror(mess);
			}
			else if (domain == DYNAMIC_PMID) {
			    pmsprintf(mess, sizeof(mess), "Dynamic metric domain field (%d) for pmid", domain);
			    yywarn(mess);
			}
			if (cluster < 0 || cluster >= 4096) {
			    pmsprintf(mess, sizeof(mess), "Illegal cluster field (%d) for pmid", cluster);
			    yyerror(mess);
			}
			current_star_metric = 0;
			free((yyvsp[0].str));
			(yyval.ival) = pmID_build(domain, cluster, 0);
		    }
#line 4557 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 184:
#line 2715 "gram.y" /* yacc.c:1648  */
    {
			int	domain;
			int	sts;
			sts = sscanf((yyvsp[0].str), "%d.", &domain);
			assert (sts == 1);
			if (domain < 1 || domain > DYNAMIC_PMID) {
			    pmsprintf(mess, sizeof(mess), "Illegal domain field (%d) for pmid", domain);
			    yyerror(mess);
			}
			else if (domain == DYNAMIC_PMID) {
			    pmsprintf(mess, sizeof(mess), "Dynamic metric domain field (%d) for pmid", domain);
			    yywarn(mess);
			}
			current_star_metric = 1;
			free((yyvsp[0].str));
			(yyval.ival) = pmID_build(domain, 0, 0);
		    }
#line 4579 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 186:
#line 2736 "gram.y" /* yacc.c:1648  */
    {
			deactivate_labels();
		    }
#line 4587 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 189:
#line 2746 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_DELETE, "delete", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_DELETE, "delete", 0)) {
			    lp->flags |= LABEL_DELETE;
			}
		    }
#line 4598 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 190:
#line 2753 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			int		cluster;
			for (lp = walk_label(W_START, LABEL_CHANGE_ID, "id", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_ID, "id", 0)) {
			    if (current_star_metric)
				cluster = pmID_build(pmID_domain((yyvsp[0].ival)), pmID_cluster(lp->old_id), PM_ID_NULL);
			    else
				cluster = pmID_build(pmID_domain((yyvsp[0].ival)), pmID_cluster((yyvsp[0].ival)), PM_ID_NULL);
			    if (cluster == lp->old_id) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for cluster: %d.%d: No change", pmID_domain(lp->old_id), pmID_cluster(lp->old_id));
				    yywarn(mess);
				}
			    }
			    else {
				/*
				 * No need to check for conflicts. Multiple label set records for
				 * the same cluster are ok.
				 */
				lp->new_id = cluster;
				lp->flags |= LABEL_CHANGE_ID;
			    }
			}
		    }
#line 4628 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 191:
#line 2779 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_CHANGE_LABEL, "label", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_LABEL, "label", 0)) {
			    if (lp->new_label != NULL) {
				pmsprintf(mess, sizeof(mess), "Duplicate label clause for cluster %d.%d", pmID_domain(lp->old_id), pmID_cluster(lp->old_id));
				yyerror(mess);
			    }
			    if (lp->old_label != NULL &&
				strcmp(lp->old_label, (yyvsp[0].str)) == 0) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for cluster %d.%d: label: No change", pmID_domain(lp->old_id), pmID_cluster(lp->old_id));
				    yywarn(mess);
				}
				free((yyvsp[0].str));
			    }
			    else {
				lp->new_label = (yyvsp[0].str);
				lp->flags |= LABEL_CHANGE_LABEL;
			    }
			}
		    }
#line 4655 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 192:
#line 2803 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_CHANGE_VALUE, "value", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_VALUE, "value", 0)) {
			    if (lp->new_value != NULL) {
				pmsprintf(mess, sizeof(mess), "Duplicate value clause for cluster %d.%d", pmID_domain(lp->old_id), pmID_cluster(lp->old_id));
				yyerror(mess);
			    }
			    if (lp->old_value != NULL &&
				strcmp(lp->old_value, (yyvsp[0].str)) == 0) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for cluster %d.%d: value: No change", pmID_domain(lp->old_id), pmID_cluster(lp->old_id));
				    yywarn(mess);
				}
				free((yyvsp[0].str));
			    }
			    else {
				lp->new_value = (yyvsp[0].str);
				lp->flags |= LABEL_CHANGE_VALUE;
			    }
			}
		    }
#line 4682 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 193:
#line 2827 "gram.y" /* yacc.c:1648  */
    {
			new_cluster_label(current_label_id);
		    }
#line 4690 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 194:
#line 2833 "gram.y" /* yacc.c:1648  */
    {
			__pmContext	*ctxp;
			__pmHashCtl	*hcp1;
			__pmHashNode	*node1;

			ctxp = __pmHandleToPtr(pmWhichContext());
			assert(ctxp != NULL);
    /*
     * Note: This application is single threaded, and once we have ctxp,
     *	     the associated __pmContext will not move and will only be
     *	     accessed or modified synchronously either here or in libpcp.
     *	     We unlock the context so that it can be locked as required
     *	     within libpcp.
     */
			PM_UNLOCK(ctxp->c_lock);
			
			current_labelspec = NULL;
			current_label_id = (yyvsp[-1].pmid);
			if ((yyvsp[-1].pmid) == PM_ID_NULL) {
			    /* Metric referenced by name is not in the archive */
			    do_walk_label = 0;
			}
			else {
			    int found = 0;
			    
			    if (current_star_metric) {
				/* Set up for metrics specified using globbing. */
				star_domain = pmID_domain((yyvsp[-1].pmid));
				if (current_star_metric == 1)
				    star_cluster = pmID_cluster((yyvsp[-1].pmid));
				else
				    star_cluster = PM_ID_NULL;
			    }

			    /* We're looking for item labels. */
			    hcp1 = &ctxp->c_archctl->ac_log->l_hashlabels;
			    for (node1 = __pmHashWalk(hcp1, PM_HASH_WALK_START);
				 node1 != NULL;
				 node1 = __pmHashWalk(hcp1, PM_HASH_WALK_NEXT)) {
				__pmHashCtl	*hcp2;
				__pmHashNode	*node2;
				int		this_type;

				/* Was this object type selected? */
				this_type = (int)(node1->key);
				if (this_type != PM_LABEL_ITEM)
				    continue;

				/*
				 * Collect the label records associated with the specified
				 * metric(s).
				 */
				hcp2 = (__pmHashCtl *)(node1->data);
				for (node2 = __pmHashWalk(hcp2, PM_HASH_WALK_START);
				     node2 != NULL;
				     node2 = __pmHashWalk(hcp2, PM_HASH_WALK_NEXT)) {
				    if (current_star_metric) {
					/* Match the globbed metric spec and keep looking. */
					if (pmID_domain((pmID)(node2->key)) == star_domain &&
					    (star_cluster == PM_ID_NULL ||
					     star_cluster == pmID_cluster((pmID)(node2->key)))) {
					    current_labelspec = start_label(this_type, (pmID)(node2->key), 0,
									    current_label_name, current_label_value);
					    if (current_labelspec) {
						current_labelspec->flags |= LABEL_ACTIVE;
						++found;
					    }

					}
				    }
				    else {
					/* Match the exact metric PMID. */
					if ((pmID)(node2->key) == (yyvsp[-1].pmid)) {
					    current_labelspec = start_label(this_type, (pmID)(node2->key), 0,
									    current_label_name, current_label_value);
					    if (current_labelspec) {
						current_labelspec->flags |= LABEL_ACTIVE;
						++found;
					    }
					}
				    }
				}
			    }
			    do_walk_label = found;
			}
		    }
#line 4781 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 197:
#line 2924 "gram.y" /* yacc.c:1648  */
    {
			deactivate_labels();
		    }
#line 4789 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 200:
#line 2934 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_DELETE, "delete", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_DELETE, "delete", 0)) {
			    lp->flags |= LABEL_DELETE;
			}
		    }
#line 4800 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 201:
#line 2941 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			pmID		pmid;
			for (lp = walk_label(W_START, LABEL_CHANGE_ID, "id", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_ID, "id", 0)) {
			    if (current_star_metric == 1)
				pmid = pmID_build(pmID_domain((yyvsp[0].pmid)), pmID_cluster((yyvsp[0].pmid)), pmID_item(lp->old_id));
			    else if (current_star_metric == 2)
				pmid = pmID_build(pmID_domain((yyvsp[0].pmid)), pmID_cluster(lp->old_id), pmID_item(lp->old_id));
			    else
				pmid = (yyvsp[0].pmid);
			    if (pmid == lp->old_id) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for metric: %s: item: No change", pmIDStr(lp->old_id));
				    yywarn(mess);
				}
			    }
			    else {
				/*
				 * No need to check for conflicts. Multiple label set records for
				 * the same pmid are ok.
				 */
				lp->new_id = pmid;
				lp->flags |= LABEL_CHANGE_ID;
			    }
			}
		    }
#line 4832 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 202:
#line 2969 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_CHANGE_LABEL, "label", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_LABEL, "label", 0)) {
			    if (lp->new_label != NULL) {
				pmsprintf(mess, sizeof(mess), "Duplicate label clause for metric %s", pmIDStr(lp->old_id));
				yyerror(mess);
			    }
			    if (lp->old_label != NULL &&
				strcmp(lp->old_label, (yyvsp[0].str)) == 0) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for metric %s: label: No change", pmIDStr(lp->old_id));
				    yywarn(mess);
				}
				free((yyvsp[0].str));
			    }
			    else {
				lp->new_label = (yyvsp[0].str);
				lp->flags |= LABEL_CHANGE_LABEL;
			    }
			}
		    }
#line 4859 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 203:
#line 2993 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_CHANGE_VALUE, "value", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_VALUE, "value", 0)) {
			    if (lp->new_value != NULL) {
				pmsprintf(mess, sizeof(mess), "Duplicate value clause for metric %s", pmIDStr(lp->old_id));
				yyerror(mess);
			    }
			    if (lp->old_value != NULL &&
				strcmp(lp->old_value, (yyvsp[0].str)) == 0) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for metric %s: value: No change", pmIDStr(lp->old_id));
				    yywarn(mess);
				}
				free((yyvsp[0].str));
			    }
			    else {
				lp->new_value = (yyvsp[0].str);
				lp->flags |= LABEL_CHANGE_VALUE;
			    }
			}
		    }
#line 4886 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 204:
#line 3017 "gram.y" /* yacc.c:1648  */
    {
			new_item_label(current_label_id);
		    }
#line 4894 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 205:
#line 3023 "gram.y" /* yacc.c:1648  */
    {
			__pmContext	*ctxp;
			__pmHashCtl	*hcp1;
			__pmHashNode	*node1;

			ctxp = __pmHandleToPtr(pmWhichContext());
			assert(ctxp != NULL);
    /*
     * Note: This application is single threaded, and once we have ctxp,
     *	     the associated __pmContext will not move and will only be
     *	     accessed or modified synchronously either here or in libpcp.
     *	     We unlock the context so that it can be locked as required
     *	     within libpcp.
     */
			PM_UNLOCK(ctxp->c_lock);
			
			current_labelspec = NULL;
			current_label_id = (yyvsp[-1].indom);
			if ((yyvsp[-1].indom) == PM_ID_NULL) {
			    /* Indom is not in the archive */
			    do_walk_label = 0;
			}
			else {
			    int found = 0;
			    
			    if (current_star_indom) {
				/* Set up for indoms specified using globbing. */
				star_domain = pmInDom_domain((yyvsp[-1].indom));
			    }

			    /* We're looking for label sets for indom(s). */
			    hcp1 = &ctxp->c_archctl->ac_log->l_hashlabels;
			    for (node1 = __pmHashWalk(hcp1, PM_HASH_WALK_START);
				 node1 != NULL;
				 node1 = __pmHashWalk(hcp1, PM_HASH_WALK_NEXT)) {
				__pmHashCtl	*hcp2;
				__pmHashNode	*node2;
				int		this_type;

				/* Was this object type selected? */
				this_type = (int)(node1->key);
				if (this_type != PM_LABEL_INDOM)
				    continue;

				/*
				 * Collect the label records associated with the specified
				 * imdom(s).
				 */
				hcp2 = (__pmHashCtl *)(node1->data);
				for (node2 = __pmHashWalk(hcp2, PM_HASH_WALK_START);
				     node2 != NULL;
				     node2 = __pmHashWalk(hcp2, PM_HASH_WALK_NEXT)) {
				    if (current_star_indom) {
					/* Match the globbed indom spec and keep looking. */
					if (pmInDom_domain((pmID)(node2->key)) == star_domain) {
					    current_labelspec = start_label(this_type, (pmID)(node2->key), 0,
									    current_label_name, current_label_value);
					    if (current_labelspec) {
						current_labelspec->flags |= LABEL_ACTIVE;
						++found;
					    }
					}
				    }
				    else {
					/* Match the exact indom id. */
					if ((pmID)(node2->key) == (yyvsp[-1].indom)) {
					    current_labelspec = start_label(this_type, (pmID)(node2->key), 0,
									    current_label_name, current_label_value);
					    if (current_labelspec) {
						current_labelspec->flags |= LABEL_ACTIVE;
						++found;
					    }
					}
				    }
				}
			    }
			    do_walk_label = found;
			}
		    }
#line 4978 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 208:
#line 3107 "gram.y" /* yacc.c:1648  */
    {
			deactivate_labels();
		    }
#line 4986 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 211:
#line 3117 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_DELETE, "delete", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_DELETE, "delete", 0)) {
			    lp->flags |= LABEL_DELETE;
			}
		    }
#line 4997 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 212:
#line 3124 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_CHANGE_ID, "id", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_ID, "id", 0)) {
			    pmInDom	indom;
			    if (lp->new_id != lp->old_id) {
				pmsprintf(mess, sizeof(mess), "Duplicate label clause for indom %s", pmInDomStr(lp->old_id));
				yyerror(mess);
			    }
			    if (current_star_indom)
				indom = pmInDom_build(pmInDom_domain((yyvsp[0].indom)), pmInDom_serial(lp->old_id));
			    else
				indom = (yyvsp[0].indom);
			    if (indom != lp->old_id) {
				lp->new_id = indom;
				lp->flags |= LABEL_CHANGE_ID;
			    }
			    else {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for instance domain %s: indom: No change", pmInDomStr(lp->old_id));
				    yywarn(mess);
				}
			    }
			}
		    }
#line 5027 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 213:
#line 3150 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_CHANGE_LABEL, "label", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_LABEL, "label", 0)) {
			    if (lp->new_label != NULL) {
				pmsprintf(mess, sizeof(mess), "Duplicate label clause for indom %s", pmInDomStr(lp->old_id));
				yyerror(mess);
			    }
			    if (lp->old_label != NULL &&
				strcmp(lp->old_label, (yyvsp[0].str)) == 0) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for instance domain %s: label: No change", pmInDomStr(lp->old_id));
				    yywarn(mess);
				}
				free((yyvsp[0].str));
			    }
			    else {
				lp->new_label = (yyvsp[0].str);
				lp->flags |= LABEL_CHANGE_LABEL;
			    }
			}
		    }
#line 5054 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 214:
#line 3174 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_CHANGE_VALUE, "value", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_VALUE, "value", 0)) {
			    if (lp->new_value != NULL) {
				pmsprintf(mess, sizeof(mess), "Duplicate value clause for indom %s", pmInDomStr(lp->old_id));
				yyerror(mess);
			    }
			    if (lp->old_value != NULL &&
				strcmp(lp->old_value, (yyvsp[0].str)) == 0) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for instance domain %s: value: No change", pmInDomStr(lp->old_id));
				    yywarn(mess);
				}
				free((yyvsp[0].str));
			    }
			    else {
				lp->new_value = (yyvsp[0].str);
				lp->flags |= LABEL_CHANGE_VALUE;
			    }
			}
		    }
#line 5081 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 215:
#line 3198 "gram.y" /* yacc.c:1648  */
    {
			new_indom_label(current_label_id);
		    }
#line 5089 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 216:
#line 3204 "gram.y" /* yacc.c:1648  */
    {
			__pmContext	*ctxp;
			__pmHashCtl	*hcp1;
			__pmHashNode	*node1;

			ctxp = __pmHandleToPtr(pmWhichContext());
			assert(ctxp != NULL);
    /*
     * Note: This application is single threaded, and once we have ctxp,
     *	     the associated __pmContext will not move and will only be
     *	     accessed or modified synchronously either here or in libpcp.
     *	     We unlock the context so that it can be locked as required
     *	     within libpcp.
     */
			PM_UNLOCK(ctxp->c_lock);
			
			current_labelspec = NULL;
			current_label_id = (yyvsp[-1].indom);
			if ((yyvsp[-1].indom) == PM_ID_NULL) {
			    /* Indom is not in the archive */
			    do_walk_label = 0;
			}
			else {
			    int found = 0;
			    
			    if (current_star_indom) {
				/* Set up for indoms specified using globbing. */
				star_domain = pmInDom_domain((yyvsp[-1].indom));
			    }

			    /* We're looking for label sets for the instances of the indom(s). */
			    hcp1 = &ctxp->c_archctl->ac_log->l_hashlabels;
			    for (node1 = __pmHashWalk(hcp1, PM_HASH_WALK_START);
				 node1 != NULL;
				 node1 = __pmHashWalk(hcp1, PM_HASH_WALK_NEXT)) {
				__pmHashCtl	*hcp2;
				__pmHashNode	*node2;
				int		this_type;

				/* Was this object type selected? */
				this_type = (int)(node1->key);
				if (this_type != PM_LABEL_INSTANCES)
				    continue;

				/*
				 * Collect the label records associated with the specified
				 * indom instance(s).
				 */
				hcp2 = (__pmHashCtl *)(node1->data);
				for (node2 = __pmHashWalk(hcp2, PM_HASH_WALK_START);
				     node2 != NULL;
				     node2 = __pmHashWalk(hcp2, PM_HASH_WALK_NEXT)) {
				    if (current_star_indom) {
					/* Match the globbed indom spec and keep looking. */
					if (pmInDom_domain((pmID)(node2->key)) == star_domain) {
					    current_labelspec = start_label(this_type, (pmID)(node2->key),
									    current_label_instance,
									    current_label_name, current_label_value);
					    if (current_labelspec) {
						current_labelspec->flags |= LABEL_ACTIVE;
						++found;
					    }
					}
				    }
				    else {
					/* Match the exact indom id. */
					if ((pmID)(node2->key) == (yyvsp[-1].indom)) {
					    current_labelspec = start_label(this_type, (pmID)(node2->key),
									    current_label_instance,
									    current_label_name, current_label_value);
					    if (current_labelspec) {
						current_labelspec->flags |= LABEL_ACTIVE;
						++found;
					    }
					}
				    }
				}
			    }
			    do_walk_label = found;
			}
		    }
#line 5175 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 218:
#line 3289 "gram.y" /* yacc.c:1648  */
    {
			current_label_instance = -1;
			current_label_name = (yyvsp[-1].str);
		    }
#line 5184 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 219:
#line 3294 "gram.y" /* yacc.c:1648  */
    {
			current_label_instance = atoi((yyvsp[-1].str));
			free((yyvsp[-1].str));
		    }
#line 5193 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 220:
#line 3299 "gram.y" /* yacc.c:1648  */
    {
			current_label_instance = -1;
		    }
#line 5201 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 221:
#line 3303 "gram.y" /* yacc.c:1648  */
    {
			current_label_instance = -1;
			current_label_name = NULL;
			current_label_value = NULL;
		    }
#line 5211 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 223:
#line 3312 "gram.y" /* yacc.c:1648  */
    {
			deactivate_labels();
		    }
#line 5219 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 226:
#line 3322 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_DELETE, "delete", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_DELETE, "delete", 0)) {
			    lp->flags |= LABEL_DELETE;
			}
		    }
#line 5230 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 227:
#line 3329 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_CHANGE_ID, "id", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_ID, "id", 0)) {
			    pmInDom	indom;
			    if (lp->new_id != lp->old_id) {
				pmsprintf(mess, sizeof(mess), "Duplicate label clause for instances of indom %s", pmInDomStr(lp->old_id));
				yyerror(mess);
			    }
			    if (current_star_indom)
				indom = pmInDom_build(pmInDom_domain((yyvsp[0].indom)), pmInDom_serial(lp->old_id));
			    else
				indom = (yyvsp[0].indom);
			    if (indom != lp->old_id) {
				lp->new_id = indom;
				lp->flags |= LABEL_CHANGE_ID;
			    }
			    else {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for instance domain %s: indom: No change", pmInDomStr(lp->old_id));
				    yywarn(mess);
				}
			    }
			}
		    }
#line 5260 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 228:
#line 3355 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_CHANGE_ID, "id", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_ID, "id", 0)) {
			    int	instance;
			    if (lp->new_instance != lp->old_instance) {
				pmsprintf(mess, sizeof(mess), "Duplicate label clause for instances of indom %s", pmInDomStr(lp->old_id));
				yyerror(mess);
			    }
			    instance = atoi((yyvsp[0].str));
			    free((yyvsp[0].str));
			    if (instance != lp->old_instance) {
				lp->new_instance = instance;
				lp->flags |= LABEL_CHANGE_INSTANCE;
			    }
			    else {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for instance domain %s instance %d: instance: No change", pmInDomStr(lp->old_id), lp->old_instance);
				    yywarn(mess);
				}
				free((yyvsp[0].str));
			    }
			}
		    }
#line 5289 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 229:
#line 3380 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_CHANGE_LABEL, "label", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_LABEL, "label", 0)) {
			    if (lp->new_label != NULL) {
				pmsprintf(mess, sizeof(mess), "Duplicate label clause for instances of indom %s", pmInDomStr(lp->old_id));
				yyerror(mess);
			    }
			    if (lp->old_label != NULL &&
				strcmp(lp->old_label, (yyvsp[0].str)) == 0) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for instances of instance domain %s: label: No change", pmInDomStr(lp->old_id));
				    yywarn(mess);
				}
				free((yyvsp[0].str));
			    }
			    else {
				lp->new_label = (yyvsp[0].str);
				lp->flags |= LABEL_CHANGE_LABEL;
			    }
			}
		    }
#line 5316 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 230:
#line 3404 "gram.y" /* yacc.c:1648  */
    {
			labelspec_t	*lp;
			for (lp = walk_label(W_START, LABEL_CHANGE_VALUE, "value", 0); lp != NULL; lp = walk_label(W_NEXT, LABEL_CHANGE_VALUE, "value", 0)) {
			    if (lp->new_value != NULL) {
				pmsprintf(mess, sizeof(mess), "Duplicate value clause for instances of indom %s", pmInDomStr(lp->old_id));
				yyerror(mess);
			    }
			    if (lp->old_value != NULL &&
				strcmp(lp->old_value, (yyvsp[0].str)) == 0) {
				/* no change ... */
				if (wflag) {
				    pmsprintf(mess, sizeof(mess), "Label for instances of instance domain %s: value: No change", pmInDomStr(lp->old_id));
				    yywarn(mess);
				}
				free((yyvsp[0].str));
			    }
			    else {
				lp->new_value = (yyvsp[0].str);
				lp->flags |= LABEL_CHANGE_VALUE;
			    }
			}
		    }
#line 5343 "gram.tab.c" /* yacc.c:1648  */
    break;

  case 231:
#line 3428 "gram.y" /* yacc.c:1648  */
    {
			new_indom_instance_label(current_label_id);
		    }
#line 5351 "gram.tab.c" /* yacc.c:1648  */
    break;


#line 5355 "gram.tab.c" /* yacc.c:1648  */
      default: break;
    }
  /* User semantic actions sometimes alter yychar, and that requires
     that yytoken be updated with the new translation.  We take the
     approach of translating immediately before every use of yytoken.
     One alternative is translating here after every semantic action,
     but that translation would be missed if the semantic action invokes
     YYABORT, YYACCEPT, or YYERROR immediately after altering yychar or
     if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
     incorrect destructor might then be invoked immediately.  In the
     case of YYERROR or YYBACKUP, subsequent parser actions might lead
     to an incorrect destructor call or verbose syntax error message
     before the lookahead is translated.  */
  YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;

  /* Now 'shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*--------------------------------------.
| yyerrlab -- here on detecting error.  |
`--------------------------------------*/
yyerrlab:
  /* Make sure we have latest lookahead translation.  See comments at
     user semantic actions for why this is necessary.  */
  yytoken = yychar == YYEMPTY ? YYEMPTY : YYTRANSLATE (yychar);

  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if ! YYERROR_VERBOSE
      yyerror (YY_("syntax error"));
#else
# define YYSYNTAX_ERROR yysyntax_error (&yymsg_alloc, &yymsg, \
                                        yyssp, yytoken)
      {
        char const *yymsgp = YY_("syntax error");
        int yysyntax_error_status;
        yysyntax_error_status = YYSYNTAX_ERROR;
        if (yysyntax_error_status == 0)
          yymsgp = yymsg;
        else if (yysyntax_error_status == 1)
          {
            if (yymsg != yymsgbuf)
              YYSTACK_FREE (yymsg);
            yymsg = (char *) YYSTACK_ALLOC (yymsg_alloc);
            if (!yymsg)
              {
                yymsg = yymsgbuf;
                yymsg_alloc = sizeof yymsgbuf;
                yysyntax_error_status = 2;
              }
            else
              {
                yysyntax_error_status = YYSYNTAX_ERROR;
                yymsgp = yymsg;
              }
          }
        yyerror (yymsgp);
        if (yysyntax_error_status == 2)
          goto yyexhaustedlab;
      }
# undef YYSYNTAX_ERROR
#endif
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
         error, discard it.  */

      if (yychar <= YYEOF)
        {
          /* Return failure if at end of input.  */
          if (yychar == YYEOF)
            YYABORT;
        }
      else
        {
          yydestruct ("Error: discarding",
                      yytoken, &yylval);
          yychar = YYEMPTY;
        }
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:

  /* Pacify compilers like GCC when the user code never invokes
     YYERROR and the label yyerrorlab therefore never appears in user
     code.  */
  if (/*CONSTCOND*/ 0)
     goto yyerrorlab;

  /* Do not reclaim the symbols of the rule whose action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;      /* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (!yypact_value_is_default (yyn))
        {
          yyn += YYTERROR;
          if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
            {
              yyn = yytable[yyn];
              if (0 < yyn)
                break;
            }
        }

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
        YYABORT;


      yydestruct ("Error: popping",
                  yystos[yystate], yyvsp);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END


  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#if !defined yyoverflow || YYERROR_VERBOSE
/*-------------------------------------------------.
| yyexhaustedlab -- memory exhaustion comes here.  |
`-------------------------------------------------*/
yyexhaustedlab:
  yyerror (YY_("memory exhausted"));
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
  if (yychar != YYEMPTY)
    {
      /* Make sure we have latest lookahead translation.  See comments at
         user semantic actions for why this is necessary.  */
      yytoken = YYTRANSLATE (yychar);
      yydestruct ("Cleanup: discarding lookahead",
                  yytoken, &yylval);
    }
  /* Do not reclaim the symbols of the rule whose action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
                  yystos[*yyssp], yyvsp);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
#if YYERROR_VERBOSE
  if (yymsg != yymsgbuf)
    YYSTACK_FREE (yymsg);
#endif
  return yyresult;
}
#line 3433 "gram.y" /* yacc.c:1907  */

